@@ -1,6 +1,6 @@
 /*
  * gibber-bytestream-ibb.c - Source for GibberBytestreamIBB
- * Copyright (C) 2007 Ltd.
+ * Copyright (C) 2007-2008 Collabora Ltd.
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -36,6 +36,9 @@
 
 #include "signals-marshal.h"
 
+/* IMPORTANT NOTE: This bytestream is not used anymore by Salut and so probably
+ * a bit rotten */
+
 /* FIXME: implement fragmentation using the "block-size" attribute */
 
 static void
@@ -531,6 +534,8 @@ gibber_bytestream_ibb_close (GibberBytestreamIface *bytestream,
      /* bytestream already closed, do nothing */
      return;
 
+  g_object_set (self, "state", GIBBER_BYTESTREAM_STATE_CLOSING, NULL);
+
   if (priv->state == GIBBER_BYTESTREAM_STATE_LOCAL_PENDING)
     {
       /* Stream was created using SI so we decline the request */
