@@ -60,6 +60,7 @@ enum
 {
   DATA_RECEIVED,
   STATE_CHANGED,
+  WRITE_BLOCKED,
   LAST_SIGNAL
 };
 
@@ -99,6 +100,8 @@ struct _GibberBytestreamIBBPrivate
   GibberTransport *transport;
   GIOChannel *listener;
   guint listener_watch;
+  gboolean write_blocked;
+  gboolean read_blocked;
 
   GibberBytestreamOOBCheckAddrFunc check_addr_func;
   gpointer check_addr_func_data;
@@ -109,6 +112,10 @@ struct _GibberBytestreamIBBPrivate
 #define GIBBER_BYTESTREAM_OOB_GET_PRIVATE(obj) \
     ((GibberBytestreamOOBPrivate *) (GibberBytestreamOOB *)obj->priv)
 
+static void gibber_bytestream_oob_do_close (GibberBytestreamOOB *self,
+    GError *error, gboolean can_wait);
+static void bytestream_closed (GibberBytestreamOOB *self);
+
 static void
 gibber_bytestream_oob_init (GibberBytestreamOOB *self)
 {
@@ -181,6 +188,38 @@ transport_disconnected_cb (GibberTransport *transport,
     }
 }
 
+static void
+change_write_blocked_state (GibberBytestreamOOB *self,
+                            gboolean blocked)
+{
+  GibberBytestreamOOBPrivate *priv = GIBBER_BYTESTREAM_OOB_GET_PRIVATE (self);
+
+  if (priv->write_blocked == blocked)
+    return;
+
+  priv->write_blocked = blocked;
+  g_signal_emit (self, signals[WRITE_BLOCKED], 0, blocked);
+}
+
+static void
+transport_buffer_empty_cb (GibberTransport *transport,
+                           GibberBytestreamOOB *self)
+{
+  GibberBytestreamOOBPrivate *priv = GIBBER_BYTESTREAM_OOB_GET_PRIVATE (self);
+
+  if (priv->state == GIBBER_BYTESTREAM_STATE_CLOSING)
+    {
+      DEBUG ("buffer is now empty. Bytestream can be closed");
+      bytestream_closed (self);
+    }
+
+  else if (priv->write_blocked)
+    {
+      DEBUG ("buffer is empty, unblock write to the bytestream");
+      change_write_blocked_state (self, FALSE);
+    }
+}
+
 static void
 set_transport (GibberBytestreamOOB *self,
                GibberTransport *transport)
@@ -196,6 +235,8 @@ set_transport (GibberBytestreamOOB *self,
       G_CALLBACK (transport_connected_cb), self);
   g_signal_connect (transport, "disconnected",
       G_CALLBACK (transport_disconnected_cb), self);
+  g_signal_connect (priv->transport, "buffer-empty",
+      G_CALLBACK (transport_buffer_empty_cb), self);
 }
 
 static void
@@ -232,7 +273,7 @@ connect_to_url (GibberBytestreamOOB *self,
    * client */
   if (!gibber_transport_get_sockaddr (
       GIBBER_TRANSPORT (priv->xmpp_connection->transport),
-      &addr, &len)) 
+      &addr, &len))
     {
       /* I'm too lazy to create more specific errors for this  as it should
        * never happen while using salut anyway.. */
@@ -365,7 +406,8 @@ xmpp_connection_stream_closed_cb (GibberXmppConnection *connection,
 {
   GibberBytestreamOOB *self = GIBBER_BYTESTREAM_OOB (userdata);
   DEBUG ("XMPP connection: stream closed. Close the OOB bytestream");
-  g_object_set (self, "state", GIBBER_BYTESTREAM_STATE_CLOSED, NULL);
+  g_object_set (self, "state", GIBBER_BYTESTREAM_STATE_CLOSING, NULL);
+  bytestream_closed (self);
 }
 
 static void
@@ -374,7 +416,8 @@ xmpp_connection_transport_disconnected_cb (GibberLLTransport *transport,
 {
   GibberBytestreamOOB *self = GIBBER_BYTESTREAM_OOB (userdata);
   DEBUG ("XMPP connection transport closed. Close the OOB bytestream");
-  g_object_set (self, "state", GIBBER_BYTESTREAM_STATE_CLOSED, NULL);
+  g_object_set (self, "state", GIBBER_BYTESTREAM_STATE_CLOSING, NULL);
+  bytestream_closed (self);
 }
 
 static void
@@ -383,7 +426,8 @@ xmpp_connection_parse_error_cb (GibberXmppConnection *connection,
 {
   GibberBytestreamOOB *self = GIBBER_BYTESTREAM_OOB (userdata);
   DEBUG ("XMPP connection: parse error. Close the OOB bytestream");
-  g_object_set (self, "state", GIBBER_BYTESTREAM_STATE_CLOSED, NULL);
+  g_object_set (self, "state", GIBBER_BYTESTREAM_STATE_CLOSING, NULL);
+  bytestream_closed (self);
 }
 
 static void
@@ -399,7 +443,14 @@ gibber_bytestream_oob_dispose (GObject *object)
 
   if (priv->state != GIBBER_BYTESTREAM_STATE_CLOSED)
     {
-      gibber_bytestream_iface_close (GIBBER_BYTESTREAM_IFACE (self), NULL);
+      if (priv->state == GIBBER_BYTESTREAM_STATE_CLOSING)
+        {
+          bytestream_closed (self);
+        }
+      else
+        {
+          gibber_bytestream_oob_do_close (self, NULL, FALSE);
+        }
     }
 
   if (priv->listener != NULL)
@@ -409,12 +460,6 @@ gibber_bytestream_oob_dispose (GObject *object)
       g_source_remove (priv->listener_watch);
     }
 
-  if (priv->transport != NULL)
-    {
-      gibber_transport_disconnect (priv->transport);
-      g_object_unref (priv->transport);
-    }
-
   if (priv->xmpp_connection != NULL)
     {
       g_signal_handlers_disconnect_matched (priv->xmpp_connection->transport,
@@ -646,6 +691,15 @@ gibber_bytestream_oob_class_init (
                   NULL, NULL,
                   g_cclosure_marshal_VOID__UINT,
                   G_TYPE_NONE, 1, G_TYPE_UINT);
+
+  signals[WRITE_BLOCKED] =
+    g_signal_new ("write-blocked",
+                  G_OBJECT_CLASS_TYPE (gibber_bytestream_oob_class),
+                  G_SIGNAL_RUN_LAST | G_SIGNAL_DETAILED,
+                  0,
+                  NULL, NULL,
+                  g_cclosure_marshal_VOID__BOOLEAN,
+                  G_TYPE_NONE, 1, G_TYPE_BOOLEAN);
 }
 
 /*
@@ -669,6 +723,13 @@ gibber_bytestream_oob_send (GibberBytestreamIface *bytestream,
       return FALSE;
     }
 
+  if (priv->write_blocked)
+    {
+      DEBUG ("can't send data for now, bytestream is blocked");
+      return FALSE;
+    }
+
+  DEBUG ("send %u bytes through bytestream", len);
   if (!gibber_transport_send (priv->transport, (const guint8 *) str, len,
         &error))
     {
@@ -679,6 +740,13 @@ gibber_bytestream_oob_send (GibberBytestreamIface *bytestream,
       return FALSE;
     }
 
+  if (!gibber_transport_buffer_is_empty (priv->transport))
+    {
+      /* We >don't want to send more data while the buffer isn't empty */
+      DEBUG ("buffer isn't empty. Block write to the bytestream");
+      change_write_blocked_state (self, TRUE);
+    }
+
   return TRUE;
 }
 
@@ -749,56 +817,9 @@ gibber_bytestream_oob_accept (GibberBytestreamIface *bytestream,
 }
 
 static void
-gibber_bytestream_oob_decline (GibberBytestreamOOB *self,
-                               GError *error)
+bytestream_closed (GibberBytestreamOOB *self)
 {
   GibberBytestreamOOBPrivate *priv = GIBBER_BYTESTREAM_OOB_GET_PRIVATE (self);
-  GibberXmppStanza *stanza;
-
-  g_return_if_fail (priv->state == GIBBER_BYTESTREAM_STATE_LOCAL_PENDING);
-
-  stanza = gibber_xmpp_stanza_build (
-      GIBBER_STANZA_TYPE_IQ, GIBBER_STANZA_SUB_TYPE_ERROR,
-      priv->self_id, priv->peer_id,
-      GIBBER_NODE_ATTRIBUTE, "id", priv->stream_init_id,
-      GIBBER_STANZA_END);
-
-  if (error != NULL && error->domain == GIBBER_XMPP_ERROR)
-    {
-      gibber_xmpp_error_to_node (error->code, stanza->node, error->message);
-    }
-  else
-    {
-      gibber_xmpp_error_to_node (XMPP_ERROR_FORBIDDEN, stanza->node,
-          "Offer Declined");
-    }
-
-  gibber_xmpp_connection_send (priv->xmpp_connection, stanza, NULL);
-
-  g_object_unref (stanza);
-}
-
-/*
- * gibber_bytestream_oob_close
- *
- * Implements gibber_bytestream_iface_close on GibberBytestreamIface
- */
-static void
-gibber_bytestream_oob_close (GibberBytestreamIface *bytestream,
-                             GError *error)
-{
-  GibberBytestreamOOB *self = GIBBER_BYTESTREAM_OOB (bytestream);
-  GibberBytestreamOOBPrivate *priv = GIBBER_BYTESTREAM_OOB_GET_PRIVATE (self);
-
-  if (priv->state == GIBBER_BYTESTREAM_STATE_CLOSED)
-     /* bytestream already closed, do nothing */
-     return;
-
-  if (priv->state == GIBBER_BYTESTREAM_STATE_LOCAL_PENDING)
-    {
-      /* Stream was created using SI so we decline the request */
-      gibber_bytestream_oob_decline (self, error);
-    }
 
   if (priv->recipient)
     {
@@ -829,9 +850,91 @@ gibber_bytestream_oob_close (GibberBytestreamIface *bytestream,
       /* We are the sender. Don't have to send anything */
     }
 
+  if (priv->transport != NULL)
+    {
+      g_signal_handlers_disconnect_matched (priv->transport,
+          G_SIGNAL_MATCH_DATA, 0, 0, NULL, NULL, self);
+      gibber_transport_disconnect (priv->transport);
+      g_object_unref (priv->transport);
+      priv->transport = NULL;
+    }
+
   g_object_set (self, "state", GIBBER_BYTESTREAM_STATE_CLOSED, NULL);
 }
 
+static void
+gibber_bytestream_oob_decline (GibberBytestreamOOB *self,
+                               GError *error)
+ {
+  GibberBytestreamOOBPrivate *priv = GIBBER_BYTESTREAM_OOB_GET_PRIVATE (self);
+  GibberXmppStanza *stanza;
+
+  g_return_if_fail (priv->state == GIBBER_BYTESTREAM_STATE_LOCAL_PENDING);
+
+  stanza = gibber_xmpp_stanza_build (
+      GIBBER_STANZA_TYPE_IQ, GIBBER_STANZA_SUB_TYPE_ERROR,
+      priv->self_id, priv->peer_id,
+      GIBBER_NODE_ATTRIBUTE, "id", priv->stream_init_id,
+      GIBBER_STANZA_END);
+
+  if (error != NULL && error->domain == GIBBER_XMPP_ERROR)
+    {
+      gibber_xmpp_error_to_node (error->code, stanza->node, error->message);
+    }
+  else
+    {
+      gibber_xmpp_error_to_node (XMPP_ERROR_FORBIDDEN, stanza->node,
+          "Offer Declined");
+    }
+
+  gibber_xmpp_connection_send (priv->xmpp_connection, stanza, NULL);
+
+  g_object_unref (stanza);
+}
+
+static void
+gibber_bytestream_oob_do_close (GibberBytestreamOOB *self,
+                                GError *error,
+                                gboolean can_wait)
+{
+  GibberBytestreamOOBPrivate *priv = GIBBER_BYTESTREAM_OOB_GET_PRIVATE (self);
+
+  if (priv->state == GIBBER_BYTESTREAM_STATE_CLOSED)
+     /* bytestream already closed, do nothing */
+     return;
+
+  if (priv->state == GIBBER_BYTESTREAM_STATE_LOCAL_PENDING)
+    {
+      /* Stream was created using SI so we decline the request */
+      gibber_bytestream_oob_decline (self, error);
+    }
+
+  g_object_set (self, "state", GIBBER_BYTESTREAM_STATE_CLOSING, NULL);
+  if (can_wait && priv->transport != NULL &&
+      !gibber_transport_buffer_is_empty (priv->transport))
+    {
+      DEBUG ("Wait transport buffer is empty before close the bytestream");
+    }
+  else
+    {
+      DEBUG ("Transport buffer is empty, we can close the bytestream");
+      bytestream_closed (self);
+    }
+}
+
+/*
+ * gibber_bytestream_oob_close
+ *
+ * Implements gibber_bytestream_iface_close on GibberBytestreamIface
+ */
+static void
+gibber_bytestream_oob_close (GibberBytestreamIface *bytestream,
+                             GError *error)
+{
+  gibber_bytestream_oob_do_close (GIBBER_BYTESTREAM_OOB (bytestream), error,
+      TRUE);
+}
+
 static GibberXmppStanza *
 make_oob_init_iq (const gchar *from,
                   const gchar *to,
@@ -904,7 +1007,7 @@ start_listen_for_connection (GibberBytestreamOOB *self)
   socklen_t len;
   #define BACKLOG 1
 
-  memset (&req, 0, sizeof(req));
+  memset (&req, 0, sizeof (req));
   req.ai_flags = AI_PASSIVE;
   req.ai_family = AF_UNSPEC;
   req.ai_socktype = SOCK_STREAM;
@@ -983,7 +1086,7 @@ start_listen_for_connection (GibberBytestreamOOB *self)
 
 error:
   if (fd > 0)
-    close(fd);
+    close (fd);
 
   if (ans != NULL)
     freeaddrinfo (ans);
@@ -1065,6 +1168,20 @@ gibber_bytestream_oob_set_check_addr_func (
   priv->check_addr_func_data = user_data;
 }
 
+void
+gibber_bytestream_oob_block_read (GibberBytestreamOOB *self,
+                                  gboolean block)
+{
+  GibberBytestreamOOBPrivate *priv = GIBBER_BYTESTREAM_OOB_GET_PRIVATE (self);
+
+  if (priv->read_blocked == block)
+    return;
+
+  priv->read_blocked = block;
+
+  DEBUG ("%s the transport bytestream", block ? "block": "unblock");
+  gibber_transport_block_receiving (priv->transport, block);
+}
 
 static void
 bytestream_iface_init (gpointer g_iface,
