@@ -37,7 +37,7 @@
 #define PACKET_HEADER_SIZE (6 + PACKET_PREFIX_LENGTH)
 
 
-static void gibber_r_multicast_packet_sender_info_free(
+static void gibber_r_multicast_packet_sender_info_free (
     GibberRMulticastPacketSenderInfo *sender_info);
 
 G_DEFINE_TYPE(GibberRMulticastPacket, gibber_r_multicast_packet, G_TYPE_OBJECT)
@@ -129,15 +129,15 @@ gibber_r_multicast_packet_finalize (GObject *object)
     gibber_r_multicast_packet_sender_info_free (
         g_array_index (self->depends, GibberRMulticastPacketSenderInfo *, i));
   }
-  g_array_free(self->depends, TRUE);
+  g_array_free (self->depends, TRUE);
 
   /* free any data held directly by the object here */
   switch (self->type) {
     case PACKET_TYPE_WHOIS_REPLY:
-      g_free(self->data.whois_reply.sender_name);
+      g_free (self->data.whois_reply.sender_name);
       break;
     case PACKET_TYPE_DATA:
-      g_free(self->data.data.payload);
+      g_free (self->data.data.payload);
       break;
     case PACKET_TYPE_ATTEMPT_JOIN:
       g_array_free (self->data.attempt_join.senders, TRUE);
@@ -151,17 +151,17 @@ gibber_r_multicast_packet_finalize (GObject *object)
     default:
       /* Nothing specific to free */;
   }
-  g_free(priv->data);
+  g_free (priv->data);
 
   G_OBJECT_CLASS (gibber_r_multicast_packet_parent_class)->finalize (object);
 }
 
 static GibberRMulticastPacketSenderInfo *
-gibber_r_multicast_packet_sender_info_new(guint32 sender_id,
+gibber_r_multicast_packet_sender_info_new (guint32 sender_id,
    guint32 expected_packet)
 {
   GibberRMulticastPacketSenderInfo *result
-      = g_slice_new(GibberRMulticastPacketSenderInfo);
+      = g_slice_new (GibberRMulticastPacketSenderInfo);
   result->sender_id = sender_id;
   result->packet_id = expected_packet;
 
@@ -169,18 +169,19 @@ gibber_r_multicast_packet_sender_info_new(guint32 sender_id,
 }
 
 static void
-gibber_r_multicast_packet_sender_info_free(
-    GibberRMulticastPacketSenderInfo *sender_info) {
-  g_slice_free(GibberRMulticastPacketSenderInfo, sender_info);
+gibber_r_multicast_packet_sender_info_free (
+    GibberRMulticastPacketSenderInfo *sender_info)
+{
+  g_slice_free (GibberRMulticastPacketSenderInfo, sender_info);
 }
 
 /* Start a new packet */
 GibberRMulticastPacket *
-gibber_r_multicast_packet_new(GibberRMulticastPacketType type,
-                              guint32 sender,
-                              gsize max_size) {
-  GibberRMulticastPacket *result = g_object_new(GIBBER_TYPE_R_MULTICAST_PACKET,
-                                                NULL);
+gibber_r_multicast_packet_new (GibberRMulticastPacketType type,
+    guint32 sender, gsize max_size)
+{
+  GibberRMulticastPacket *result =
+      g_object_new (GIBBER_TYPE_R_MULTICAST_PACKET, NULL);
   GibberRMulticastPacketPrivate *priv =
       GIBBER_R_MULTICAST_PACKET_GET_PRIVATE(result);
 
@@ -193,15 +194,15 @@ gibber_r_multicast_packet_new(GibberRMulticastPacketType type,
   switch (result->type) {
     case PACKET_TYPE_ATTEMPT_JOIN:
       result->data.attempt_join.senders = g_array_new (FALSE, FALSE,
-          sizeof(guint32));
+          sizeof (guint32));
       break;
     case PACKET_TYPE_JOIN:
       result->data.join.failures = g_array_new (FALSE, FALSE,
-          sizeof(guint32));
+          sizeof (guint32));
       break;
     case PACKET_TYPE_FAILURE:
       result->data.failure.failures = g_array_new (FALSE, FALSE,
-          sizeof(guint32));
+          sizeof (guint32));
       break;
     default:
       break;
@@ -211,17 +212,16 @@ gibber_r_multicast_packet_new(GibberRMulticastPacketType type,
 }
 
 gboolean
-gibber_r_multicast_packet_add_sender_info(GibberRMulticastPacket *packet,
-                                          guint32 sender_id,
-                                          guint32 packet_id,
-                                          GError **error) {
+gibber_r_multicast_packet_add_sender_info (GibberRMulticastPacket *packet,
+    guint32 sender_id, guint32 packet_id, GError **error)
+{
   GibberRMulticastPacketSenderInfo *s =
-      gibber_r_multicast_packet_sender_info_new(sender_id, packet_id);
+      gibber_r_multicast_packet_sender_info_new (sender_id, packet_id);
   GibberRMulticastPacketPrivate *priv =
       GIBBER_R_MULTICAST_PACKET_GET_PRIVATE (packet);
 
-  g_assert(priv->data == NULL);
-  g_assert(GIBBER_R_MULTICAST_PACKET_IS_RELIABLE_PACKET (packet)
+  g_assert (priv->data == NULL);
+  g_assert (GIBBER_R_MULTICAST_PACKET_IS_RELIABLE_PACKET (packet)
       || packet->type == PACKET_TYPE_SESSION);
 
   g_array_append_val (packet->depends, s);
@@ -239,10 +239,10 @@ gibber_r_multicast_packet_set_packet_id (GibberRMulticastPacket *packet,
 }
 
 void
-gibber_r_multicast_packet_set_data_info(GibberRMulticastPacket *packet,
+gibber_r_multicast_packet_set_data_info (GibberRMulticastPacket *packet,
     guint16 stream_id, guint8 flags, guint32 size)
 {
-  g_assert(packet->type == PACKET_TYPE_DATA);
+  g_assert (packet->type == PACKET_TYPE_DATA);
 
   packet->data.data.flags = flags;
   packet->data.data.total_size = size;
@@ -270,7 +270,7 @@ gibber_r_multicast_packet_set_whois_request_info (
 }
 
 void
-gibber_r_multicast_packet_set_whois_reply_info(GibberRMulticastPacket *packet,
+gibber_r_multicast_packet_set_whois_reply_info (GibberRMulticastPacket *packet,
    const gchar *name)
 {
   g_assert (packet->type == PACKET_TYPE_WHOIS_REPLY);
@@ -280,7 +280,7 @@ gibber_r_multicast_packet_set_whois_reply_info(GibberRMulticastPacket *packet,
 
 
 static gsize
-gibber_r_multicast_packet_calculate_size(GibberRMulticastPacket *packet)
+gibber_r_multicast_packet_calculate_size (GibberRMulticastPacket *packet)
 {
 
     /* 8 bit type, 8 bit version, 32 bit sender */
@@ -300,8 +300,8 @@ gibber_r_multicast_packet_calculate_size(GibberRMulticastPacket *packet)
       result += 4;
       break;
     case PACKET_TYPE_WHOIS_REPLY:
-      g_assert(packet->data.whois_reply.sender_name != NULL);
-      result += 1 + strlen(packet->data.whois_reply.sender_name);
+      g_assert (packet->data.whois_reply.sender_name != NULL);
+      result += 1 + strlen (packet->data.whois_reply.sender_name);
       break;
     case PACKET_TYPE_DATA:
       /* 8 bit flags, 32 bit data size, 16 bit stream id */
@@ -336,132 +336,142 @@ gibber_r_multicast_packet_calculate_size(GibberRMulticastPacket *packet)
 }
 
 static void
-add_guint8(guint8 *data, gsize length, gsize *offset, guint8 i) {
-  g_assert(*offset + 1 <= length);
+add_guint8 (guint8 *data, gsize length, gsize *offset, guint8 i)
+{
+  g_assert (*offset + 1 <= length);
   *(data + *offset) = i;
   (*offset)++;
 }
 
 static guint8
-get_guint8(const guint8 *data, gsize length, gsize *offset) {
+get_guint8 (const guint8 *data, gsize length, gsize *offset)
+{
   guint8 i;
-  g_assert(*offset + 1 <= length);
+  g_assert (*offset + 1 <= length);
   i = *(data + *offset);
   (*offset)++;
   return i;
 }
 
 static void
-add_guint16(guint8 *data, gsize length, gsize *offset, guint16 i) {
-  guint16 ni = htons(i);
+add_guint16 (guint8 *data, gsize length, gsize *offset, guint16 i)
+{
+  guint16 ni = htons (i);
 
-  g_assert(*offset + 2 <= length);
+  g_assert (*offset + 2 <= length);
 
-  memcpy(data + *offset, &ni, 2);
+  memcpy (data + *offset, &ni, 2);
   (*offset) += 2;
 }
 
 static guint16
-get_guint16(const guint8 *data, gsize length, gsize *offset) {
+get_guint16 (const guint8 *data, gsize length, gsize *offset)
+{
   guint16 ni;
-  g_assert(*offset + 2 <= length);
+  g_assert (*offset + 2 <= length);
 
-  memcpy(&ni, data + *offset, 2);
-  (*offset)+=2;
+  memcpy (&ni, data + *offset, 2);
+  (*offset) += 2;
 
-  return ntohs(ni);
+  return ntohs (ni);
 }
 
 static void
-add_guint32(guint8 *data, gsize length, gsize *offset, guint32 i) {
-  guint32 ni = htonl(i);
+add_guint32 (guint8 *data, gsize length, gsize *offset, guint32 i)
+{
+  guint32 ni = htonl (i);
 
-  g_assert(*offset + 4 <= length);
+  g_assert (*offset + 4 <= length);
 
-  memcpy(data + *offset, &ni, 4);
+  memcpy (data + *offset, &ni, 4);
   (*offset) += 4;
 }
 
 static guint32
-get_guint32(const guint8 *data, gsize length, gsize *offset) {
+get_guint32 (const guint8 *data, gsize length, gsize *offset)
+{
   guint32 ni;
 
-  g_assert(*offset + 4 <= length);
+  g_assert (*offset + 4 <= length);
 
-  memcpy(&ni, data + *offset, 4);
+  memcpy (&ni, data + *offset, 4);
   (*offset) += 4;
-  return ntohl(ni);
+  return ntohl (ni);
 }
 
 static void
-add_string(guint8 *data, gsize length, gsize *offset, const gchar *str) {
-  gsize len = strlen(str);
+add_string (guint8 *data, gsize length, gsize *offset, const gchar *str)
+{
+  gsize len = strlen (str);
 
-  g_assert(len < G_MAXUINT8);
-  add_guint8(data, length, offset, len);
+  g_assert (len < G_MAXUINT8);
+  add_guint8 (data, length, offset, len);
 
-  g_assert(*offset + len <= length);
-  memcpy(data + *offset, str, len);
+  g_assert (*offset + len <= length);
+  memcpy (data + *offset, str, len);
   (*offset) += len;
 }
 
 static gchar *
-get_string(const guint8 *data, gsize length, gsize *offset) {
+get_string (const guint8 *data, gsize length, gsize *offset)
+{
   gsize len;
   gchar *str;
 
   if (*offset + 1 > length)
     return NULL;
 
-  len = get_guint8(data, length, offset);
+  len = get_guint8 (data, length, offset);
 
   if (*offset + len > length)
     return NULL;
 
-  str = g_strndup((gchar *)data + *offset, len);
+  str = g_strndup ((gchar *)data + *offset, len);
   (*offset) += len;
   return str;
 }
 
 static void
-add_sender_info(guint8 *data, gsize length, gsize *offset, GArray *senders)
+add_sender_info (guint8 *data, gsize length, gsize *offset, GArray *senders)
 {
   int i;
 
-  add_guint8(data, length, offset, senders->len);
+  add_guint8 (data, length, offset, senders->len);
 
   for (i = 0; i < senders->len; i++)
     {
       GibberRMulticastPacketSenderInfo *info =
           g_array_index (senders, GibberRMulticastPacketSenderInfo *, i);
-      add_guint32(data, length, offset, info->sender_id);
-      add_guint32(data, length, offset, info->packet_id);
+      add_guint32 (data, length, offset, info->sender_id);
+      add_guint32 (data, length, offset, info->packet_id);
     }
 }
 
 static gboolean
-get_sender_info(guint8 *data, gsize length, gsize *offset, GArray *depends) {
+get_sender_info (guint8 *data, gsize length, gsize *offset, GArray *depends)
+{
   guint8 nr_items;
 
   if (*offset + 1 > length)
     return FALSE;
 
-  nr_items = get_guint8(data, length, offset);
+  nr_items = get_guint8 (data, length, offset);
 
-  for (; nr_items > 0; nr_items--) {
-    GibberRMulticastPacketSenderInfo *sender_info;
-    guint32 sender_id;
-    guint32 packet_id;
+  for (; nr_items > 0; nr_items--)
+    {
+      GibberRMulticastPacketSenderInfo *sender_info;
+      guint32 sender_id;
+      guint32 packet_id;
 
-    if (*offset + 8 > length)
-      return FALSE;
+      if (*offset + 8 > length)
+        return FALSE;
 
-    sender_id = get_guint32(data, length, offset);
-    packet_id = get_guint32(data, length, offset);
-    sender_info =
-        gibber_r_multicast_packet_sender_info_new(sender_id, packet_id);
-    g_array_append_val (depends, sender_info);
-  }
+      sender_id = get_guint32 (data, length, offset);
+      packet_id = get_guint32 (data, length, offset);
+      sender_info =
+        gibber_r_multicast_packet_sender_info_new (sender_id, packet_id);
+      g_array_append_val (depends, sender_info);
+    }
 
   return TRUE;
 }
@@ -478,23 +488,25 @@ packet_add_prefix (guint8 *data, gsize length, gsize *offset)
 }
 
 static void
-gibber_r_multicast_packet_build(GibberRMulticastPacket *packet) {
+gibber_r_multicast_packet_build (GibberRMulticastPacket *packet)
+{
   GibberRMulticastPacketPrivate *priv =
      GIBBER_R_MULTICAST_PACKET_GET_PRIVATE (packet);
   gsize needed_size;
 
-  if (priv->data != NULL) {
-    /* Already serialized return cached version */
-    return;
-  }
+  if (priv->data != NULL)
+    {
+      /* Already serialized return cached version */
+      return;
+    }
 
-  needed_size = gibber_r_multicast_packet_calculate_size(packet);
+  needed_size = gibber_r_multicast_packet_calculate_size (packet);
 
-  g_assert(needed_size <= priv->max_data);
+  g_assert (needed_size <= priv->max_data);
 
   /* Trim down the maximum data size to what we actually need */
   priv->max_data = needed_size;
-  priv->data = g_malloc0(priv->max_data);
+  priv->data = g_malloc0 (priv->max_data);
   priv->size = 0;
 
   packet_add_prefix (priv->data, priv->max_data, &(priv->size));
@@ -502,12 +514,13 @@ gibber_r_multicast_packet_build(GibberRMulticastPacket *packet) {
   add_guint8 (priv->data, priv->max_data, &(priv->size), packet->type);
   add_guint32 (priv->data, priv->max_data, &(priv->size), packet->sender);
 
-  if (GIBBER_R_MULTICAST_PACKET_IS_RELIABLE_PACKET(packet)) {
-    /* Add common reliable packet data */
-    add_guint32 (priv->data, priv->max_data, &(priv->size),
-      packet->packet_id);
-    add_sender_info (priv->data, priv->max_data, &(priv->size),
-      packet->depends);
+  if (GIBBER_R_MULTICAST_PACKET_IS_RELIABLE_PACKET (packet))
+    {
+      /* Add common reliable packet data */
+      add_guint32 (priv->data, priv->max_data, &(priv->size),
+        packet->packet_id);
+      add_sender_info (priv->data, priv->max_data, &(priv->size),
+        packet->depends);
   }
 
   switch (packet->type) {
@@ -516,7 +529,7 @@ gibber_r_multicast_packet_build(GibberRMulticastPacket *packet) {
           packet->data.whois_request.sender_id);
       break;
     case PACKET_TYPE_WHOIS_REPLY:
-      add_string(priv->data, priv->max_data, &(priv->size),
+      add_string (priv->data, priv->max_data, &(priv->size),
           packet->data.whois_reply.sender_name);
       break;
     case PACKET_TYPE_DATA:
@@ -527,9 +540,9 @@ gibber_r_multicast_packet_build(GibberRMulticastPacket *packet) {
       add_guint32 (priv->data, priv->max_data, &(priv->size),
           packet->data.data.total_size);
 
-      g_assert(priv->size + packet->data.data.payload_size == priv->max_data);
+      g_assert (priv->size + packet->data.data.payload_size == priv->max_data);
 
-      memcpy(priv->data + priv->size, packet->data.data.payload,
+      memcpy (priv->data + priv->size, packet->data.data.payload,
           packet->data.data.payload_size);
       priv->size += packet->data.data.payload_size;
       break;
@@ -581,28 +594,29 @@ gibber_r_multicast_packet_build(GibberRMulticastPacket *packet) {
     case PACKET_TYPE_NO_DATA:
       break;
     default:
-      g_assert_not_reached();
+      g_assert_not_reached ();
   }
 
   /* If this fails our size precalculation is buggy */
-  g_assert(priv->size == priv->max_data);
+  g_assert (priv->size == priv->max_data);
 }
 
 gsize
-gibber_r_multicast_packet_add_payload(GibberRMulticastPacket *packet,
-                                      const guint8 *data, gsize size) {
+gibber_r_multicast_packet_add_payload (GibberRMulticastPacket *packet,
+  const guint8 *data, gsize size)
+{
   GibberRMulticastPacketPrivate *priv =
      GIBBER_R_MULTICAST_PACKET_GET_PRIVATE (packet);
   gsize avail;
 
-  g_assert(packet->type == PACKET_TYPE_DATA);
-  g_assert(packet->data.data.payload == NULL);
-  g_assert(priv->data == NULL);
+  g_assert (packet->type == PACKET_TYPE_DATA);
+  g_assert (packet->data.data.payload == NULL);
+  g_assert (priv->data == NULL);
 
-  avail = MIN(size, priv->max_data -
-    gibber_r_multicast_packet_calculate_size(packet));
+  avail = MIN (size, priv->max_data -
+    gibber_r_multicast_packet_calculate_size (packet));
 
-  packet->data.data.payload = g_memdup(data, avail);
+  packet->data.data.payload = g_memdup (data, avail);
   packet->data.data.payload_size = avail;
 
   return avail;
@@ -641,8 +655,9 @@ packet_check_prefix (const guint8 *data)
 
 /* Create a packet by parsing raw data, packet is immutable afterwards */
 GibberRMulticastPacket *
-gibber_r_multicast_packet_parse(const guint8 *data, gsize size,
-    GError **error) {
+gibber_r_multicast_packet_parse (const guint8 *data, gsize size,
+    GError **error)
+{
   GibberRMulticastPacket *result = NULL;
 
   GibberRMulticastPacketPrivate *priv;
@@ -650,10 +665,10 @@ gibber_r_multicast_packet_parse(const guint8 *data, gsize size,
   if (size < PACKET_HEADER_SIZE || !packet_check_prefix (data))
     goto parse_error;
 
-  result = g_object_new(GIBBER_TYPE_R_MULTICAST_PACKET, NULL);
-  priv = GIBBER_R_MULTICAST_PACKET_GET_PRIVATE(result);
+  result = g_object_new (GIBBER_TYPE_R_MULTICAST_PACKET, NULL);
+  priv = GIBBER_R_MULTICAST_PACKET_GET_PRIVATE (result);
 
-  priv->data = g_memdup(data, size);
+  priv->data = g_memdup (data, size);
   priv->size = PACKET_PREFIX_LENGTH;
   priv->max_data = size;
 
@@ -665,19 +680,20 @@ gibber_r_multicast_packet_parse(const guint8 *data, gsize size,
   GET_GUINT32 (result->sender);
 
 
-  if (GIBBER_R_MULTICAST_PACKET_IS_RELIABLE_PACKET (result)) {
-    GET_GUINT32 (result->packet_id);
-    if (!get_sender_info (priv->data, priv->max_data, &(priv->size),
-        result->depends))
-      goto parse_error;
-  }
+  if (GIBBER_R_MULTICAST_PACKET_IS_RELIABLE_PACKET (result))
+    {
+      GET_GUINT32 (result->packet_id);
+      if (!get_sender_info (priv->data, priv->max_data, &(priv->size),
+          result->depends))
+        goto parse_error;
+    }
 
   switch (result->type) {
     case PACKET_TYPE_WHOIS_REQUEST:
       GET_GUINT32 (result->data.whois_request.sender_id);
       break;
     case PACKET_TYPE_WHOIS_REPLY:
-      result->data.whois_reply.sender_name = get_string(priv->data,
+      result->data.whois_reply.sender_name = get_string (priv->data,
           priv->max_data, &(priv->size));
       if (result->data.whois_reply.sender_name == NULL)
         goto parse_error;
@@ -688,7 +704,7 @@ gibber_r_multicast_packet_parse(const guint8 *data, gsize size,
       GET_GUINT32 (result->data.data.total_size);
 
       result->data.data.payload_size = priv->max_data - priv->size;
-      result->data.data.payload = g_memdup(priv->data + priv->size,
+      result->data.data.payload = g_memdup (priv->data + priv->size,
           result->data.data.payload_size);
       priv->size += result->data.data.payload_size;
       break;
@@ -696,61 +712,66 @@ gibber_r_multicast_packet_parse(const guint8 *data, gsize size,
       GET_GUINT32 (result->data.repair_request.sender_id);
       GET_GUINT32 (result->data.repair_request.packet_id);
       break;
-    case PACKET_TYPE_ATTEMPT_JOIN: {
-      guint8 nr;
-      guint8 i;
+    case PACKET_TYPE_ATTEMPT_JOIN:
+      {
+        guint8 nr;
+        guint8 i;
 
-      GET_GUINT8 (nr);
+        GET_GUINT8 (nr);
 
-      result->data.attempt_join.senders = g_array_sized_new (FALSE, FALSE,
-          sizeof (guint32), nr);
+        result->data.attempt_join.senders = g_array_sized_new (FALSE, FALSE,
+            sizeof (guint32), nr);
 
-      for (i = 0; i < nr; i++) {
-        guint32 sender;
-        GET_GUINT32 (sender);
-        gibber_r_multicast_packet_attempt_join_add_sender (result,
-            sender, NULL);
+        for (i = 0; i < nr; i++)
+          {
+            guint32 sender;
+            GET_GUINT32 (sender);
+            gibber_r_multicast_packet_attempt_join_add_sender (result,
+              sender, NULL);
+          }
+        break;
       }
-      break;
-    }
-    case PACKET_TYPE_JOIN: {
-      guint8 nr;
-      guint8 i;
+    case PACKET_TYPE_JOIN:
+      {
+        guint8 nr;
+        guint8 i;
 
-      GET_GUINT8 (nr);
+        GET_GUINT8 (nr);
 
-      result->data.join.failures = g_array_sized_new (FALSE, FALSE,
-          sizeof (guint32), nr);
+        result->data.join.failures = g_array_sized_new (FALSE, FALSE,
+            sizeof (guint32), nr);
 
-      for (i = 0; i < nr; i++) {
-        guint32 failure;
+        for (i = 0; i < nr; i++) {
+          guint32 failure;
 
-        GET_GUINT32 (failure);
-        gibber_r_multicast_packet_join_add_failure (result,
-            failure, NULL);
+          GET_GUINT32 (failure);
+          gibber_r_multicast_packet_join_add_failure (result,
+              failure, NULL);
+        }
+        break;
       }
-      break;
-    }
-    case PACKET_TYPE_FAILURE: {
-      guint8 nr;
-      guint8 i;
+    case PACKET_TYPE_FAILURE:
+      {
+        guint8 nr;
+        guint8 i;
 
-      GET_GUINT8 (nr);
+        GET_GUINT8 (nr);
 
-      result->data.failure.failures = g_array_sized_new (FALSE, FALSE,
-          sizeof (guint32), nr);
+        result->data.failure.failures = g_array_sized_new (FALSE, FALSE,
+            sizeof (guint32), nr);
 
-      for (i = 0; i < nr; i++) {
-        guint32 sender;
+        for (i = 0; i < nr; i++)
+          {
+            guint32 sender;
 
-        GET_GUINT32 (sender);
-        gibber_r_multicast_packet_failure_add_sender (result,
-            sender, NULL);
+            GET_GUINT32 (sender);
+            gibber_r_multicast_packet_failure_add_sender (result,
+                sender, NULL);
+          }
+        break;
       }
-      break;
-    }
     case PACKET_TYPE_SESSION:
-      if (!get_sender_info(priv->data, priv->max_data, &(priv->size),
+      if (!get_sender_info (priv->data, priv->max_data, &(priv->size),
           result->depends))
         goto parse_error;
       break;
@@ -780,8 +801,9 @@ parse_error:
 
 /* Get the packets payload */
 guint8 *
-gibber_r_multicast_packet_get_payload(GibberRMulticastPacket *packet,
-                                      gsize *size) {
+gibber_r_multicast_packet_get_payload (GibberRMulticastPacket *packet,
+    gsize *size)
+{
   g_assert (packet->type == PACKET_TYPE_DATA);
   g_assert (size != NULL);
 
@@ -792,13 +814,14 @@ gibber_r_multicast_packet_get_payload(GibberRMulticastPacket *packet,
 
 /* Get the packets raw data, packet is immutable after this call */
 guint8 *
-gibber_r_multicast_packet_get_raw_data(GibberRMulticastPacket *packet,
-                                       gsize *size) {
+gibber_r_multicast_packet_get_raw_data (GibberRMulticastPacket *packet,
+    gsize *size)
+{
   GibberRMulticastPacketPrivate *priv =
      GIBBER_R_MULTICAST_PACKET_GET_PRIVATE (packet);
 
  /* Ensure the packet is serialized */
- gibber_r_multicast_packet_build(packet);
+ gibber_r_multicast_packet_build (packet);
 
  *size = priv->size;
 
@@ -821,9 +844,7 @@ gibber_r_multicast_packet_attempt_join_add_sender (
 /* Add senders that have failed */
 gboolean
 gibber_r_multicast_packet_attempt_join_add_senders (
-   GibberRMulticastPacket *packet,
-   GArray *senders,
-   GError **error)
+   GibberRMulticastPacket *packet, GArray *senders, GError **error)
 {
   g_assert (packet->type == PACKET_TYPE_ATTEMPT_JOIN);
 
@@ -847,8 +868,7 @@ gibber_r_multicast_packet_join_add_failure (GibberRMulticastPacket *packet,
 
 gboolean
 gibber_r_multicast_packet_join_add_failures (GibberRMulticastPacket *packet,
-   GArray *failures,
-   GError **error)
+   GArray *failures, GError **error)
 {
   g_assert (packet->type == PACKET_TYPE_JOIN);
 
@@ -859,10 +879,8 @@ gibber_r_multicast_packet_join_add_failures (GibberRMulticastPacket *packet,
 }
 
 gboolean
-gibber_r_multicast_packet_failure_add_sender (
-   GibberRMulticastPacket *packet,
-   guint32 sender,
-   GError **error)
+gibber_r_multicast_packet_failure_add_sender (GibberRMulticastPacket *packet,
+   guint32 sender, GError **error)
 {
   g_assert (packet->type == PACKET_TYPE_FAILURE);
 
@@ -873,9 +891,7 @@ gibber_r_multicast_packet_failure_add_sender (
 
 gboolean
 gibber_r_multicast_packet_failure_add_senders (
-   GibberRMulticastPacket *packet,
-   GArray *senders,
-   GError **error)
+   GibberRMulticastPacket *packet, GArray *senders, GError **error)
 {
   g_assert (packet->type == PACKET_TYPE_FAILURE);
 
@@ -886,16 +902,16 @@ gibber_r_multicast_packet_failure_add_senders (
 }
 
 gint32
-gibber_r_multicast_packet_diff(guint32 from, guint32 to) {
-  if (from > (G_MAXUINT32 - 0xffff) && to < 0xffff) {
+gibber_r_multicast_packet_diff (guint32 from, guint32 to)
+{
+  if (from > (G_MAXUINT32 - 0xffff) && to < 0xffff)
     return G_MAXUINT32 - from + to + 1;
-  }
-  if (to > (G_MAXUINT32 - 0xffff) && from < 0xffff) {
+
+  if (to > (G_MAXUINT32 - 0xffff) && from < 0xffff)
     return - from - (G_MAXUINT32 - to) - 1;
-  }
-  if (from > to) {
+
+  if (from > to)
     return -MIN(from - to, G_MAXINT);
-  }
 
   return MIN(to - from, G_MAXINT);
 }
