@@ -179,7 +179,7 @@ gibber_r_multicast_transport_set_property (GObject *object,
   switch (property_id) {
     case PROP_TRANSPORT:
       priv->transport = GIBBER_R_MULTICAST_CAUSAL_TRANSPORT (
-          g_value_dup_object(value));
+          g_value_dup_object (value));
       break;
     default:
       G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
@@ -189,20 +189,20 @@ gibber_r_multicast_transport_set_property (GObject *object,
 
 static void
 gibber_r_multicast_transport_get_property (GObject *object,
-                                           guint property_id,
-                                           GValue *value,
-                                           GParamSpec *pspec) {
-  GibberRMulticastTransport *transport = GIBBER_R_MULTICAST_TRANSPORT(object);
+  guint property_id, GValue *value, GParamSpec *pspec)
+{
+  GibberRMulticastTransport *transport = GIBBER_R_MULTICAST_TRANSPORT (object);
   GibberRMulticastTransportPrivate *priv =
-      GIBBER_R_MULTICAST_TRANSPORT_GET_PRIVATE(transport);
-  switch (property_id) {
-    case PROP_TRANSPORT:
-      g_value_set_object(value, priv->transport);
-      break;
-    default:
-      G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-      break;
-  }
+      GIBBER_R_MULTICAST_TRANSPORT_GET_PRIVATE (transport);
+  switch (property_id)
+    {
+      case PROP_TRANSPORT:
+        g_value_set_object (value, priv->transport);
+        break;
+      default:
+        G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+        break;
+    }
 }
 
 
@@ -215,18 +215,18 @@ gibber_r_multicast_transport_init (GibberRMulticastTransport *obj)
   priv->members = g_hash_table_new_full (g_int_hash, g_int_equal,
       NULL, free_member_info);
 
-  priv->pending_failures = g_array_new (FALSE, FALSE, sizeof(guint32));
+  priv->pending_failures = g_array_new (FALSE, FALSE, sizeof (guint32));
 }
 
 static void gibber_r_multicast_transport_dispose (GObject *object);
 static void gibber_r_multicast_transport_finalize (GObject *object);
 
-static gboolean
-gibber_r_multicast_transport_do_send(GibberTransport *transport,
-                                     const guint8 *data, gsize size,
-                                     GError **error);
-static void
-gibber_r_multicast_transport_disconnect(GibberTransport *transport);
+static gboolean gibber_r_multicast_transport_do_send (
+    GibberTransport *transport, const guint8 *data, gsize size,
+    GError **error);
+
+static void gibber_r_multicast_transport_disconnect (
+    GibberTransport *transport);
 
 static void
 gibber_r_multicast_transport_class_init (
@@ -244,36 +244,34 @@ gibber_r_multicast_transport_class_init (
   object_class->dispose = gibber_r_multicast_transport_dispose;
   object_class->finalize = gibber_r_multicast_transport_finalize;
 
-  signals[NEW_SENDERS] =
-    g_signal_new("new-senders",
-                 G_OBJECT_CLASS_TYPE(gibber_r_multicast_transport_class),
-                 G_SIGNAL_RUN_LAST,
-                 0,
-                 NULL, NULL,
-                 g_cclosure_marshal_VOID__POINTER,
-                 G_TYPE_NONE, 1, G_TYPE_POINTER);
+  signals[NEW_SENDERS] = g_signal_new ("new-senders",
+      G_OBJECT_CLASS_TYPE(gibber_r_multicast_transport_class),
+      G_SIGNAL_RUN_LAST,
+      0,
+      NULL, NULL,
+      g_cclosure_marshal_VOID__POINTER,
+      G_TYPE_NONE, 1, G_TYPE_POINTER);
 
-  signals[LOST_SENDERS] =
-    g_signal_new("lost-senders",
-                 G_OBJECT_CLASS_TYPE(gibber_r_multicast_transport_class),
-                 G_SIGNAL_RUN_LAST,
-                 0,
-                 NULL, NULL,
-                 g_cclosure_marshal_VOID__POINTER,
-                 G_TYPE_NONE, 1, G_TYPE_POINTER);
+  signals[LOST_SENDERS] = g_signal_new ("lost-senders",
+      G_OBJECT_CLASS_TYPE(gibber_r_multicast_transport_class),
+      G_SIGNAL_RUN_LAST,
+      0,
+      NULL, NULL,
+      g_cclosure_marshal_VOID__POINTER,
+      G_TYPE_NONE, 1, G_TYPE_POINTER);
 
   object_class->set_property = gibber_r_multicast_transport_set_property;
   object_class->get_property = gibber_r_multicast_transport_get_property;
 
-  param_spec = g_param_spec_object("transport",
-                                   "transport",
-                                   "The underlying Transport",
-                                   GIBBER_TYPE_TRANSPORT,
-                                   G_PARAM_CONSTRUCT_ONLY |
-                                   G_PARAM_READWRITE      |
-                                   G_PARAM_STATIC_NAME    |
-                                   G_PARAM_STATIC_BLURB);
-  g_object_class_install_property(object_class, PROP_TRANSPORT,
+  param_spec = g_param_spec_object ("transport",
+     "transport", "The underlying Transport",
+      GIBBER_TYPE_TRANSPORT,
+      G_PARAM_CONSTRUCT_ONLY |
+      G_PARAM_READWRITE      |
+      G_PARAM_STATIC_NAME    |
+      G_PARAM_STATIC_BLURB);
+
+  g_object_class_install_property (object_class, PROP_TRANSPORT,
                                   param_spec);
 
   transport_class->send = gibber_r_multicast_transport_do_send;
@@ -289,31 +287,36 @@ gibber_r_multicast_transport_flush_state (GibberRMulticastTransport *self)
   priv->repeating_join = FALSE;
   priv->send_empty = FALSE;
 
-  if (priv->timeout != 0) {
-    g_source_remove (priv->timeout);
-    priv->timeout = 0;
-  }
+  if (priv->timeout != 0)
+    {
+      g_source_remove (priv->timeout);
+      priv->timeout = 0;
+    }
 
-  if (priv->joining_timeout != 0) {
-    g_source_remove (priv->joining_timeout);
-    priv->joining_timeout = 0;
-  }
+  if (priv->joining_timeout != 0)
+    {
+      g_source_remove (priv->joining_timeout);
+      priv->joining_timeout = 0;
+    }
 
-  if (priv->send_join != NULL) {
-    g_array_free (priv->send_join, TRUE);
-    priv->send_join = NULL;
-  }
+  if (priv->send_join != NULL)
+    {
+      g_array_free (priv->send_join, TRUE);
+      priv->send_join = NULL;
+    }
 
-  if (priv->send_join_failures != NULL) {
-    g_array_free (priv->send_join_failures, TRUE);
-    priv->send_join_failures = NULL;
-  }
+  if (priv->send_join_failures != NULL)
+    {
+      g_array_free (priv->send_join_failures, TRUE);
+      priv->send_join_failures = NULL;
+    }
 
   if (priv->pending_failures->len > 0)
     {
       g_array_remove_range (priv->pending_failures, 0,
           priv->pending_failures->len);
     }
+
   g_hash_table_remove_all (priv->members);
 }
 
@@ -331,10 +334,11 @@ gibber_r_multicast_transport_dispose (GObject *object)
 
   gibber_r_multicast_transport_flush_state (self);
 
-  if (priv->transport != NULL) {
-    g_object_unref(priv->transport);
-    priv->transport = NULL;
-  }
+  if (priv->transport != NULL)
+    {
+      g_object_unref (priv->transport);
+      priv->transport = NULL;
+    }
 
   /* release any references held by the object here */
   if (G_OBJECT_CLASS (gibber_r_multicast_transport_parent_class)->dispose)
@@ -343,7 +347,8 @@ gibber_r_multicast_transport_dispose (GObject *object)
 }
 
 void
-gibber_r_multicast_transport_finalize (GObject *object) {
+gibber_r_multicast_transport_finalize (GObject *object)
+{
   GibberRMulticastTransport *self = GIBBER_R_MULTICAST_TRANSPORT (object);
      GibberRMulticastTransportPrivate *priv =
         GIBBER_R_MULTICAST_TRANSPORT_GET_PRIVATE (self);
@@ -406,15 +411,14 @@ received_data (GibberTransport *transport, GibberBuffer *buffer,
 }
 
 GibberRMulticastTransport *
-gibber_r_multicast_transport_new(GibberRMulticastCausalTransport *transport)
+gibber_r_multicast_transport_new (GibberRMulticastCausalTransport *transport)
 {
   GibberRMulticastTransport *result;
 
-  result =  g_object_new(GIBBER_TYPE_R_MULTICAST_TRANSPORT,
-                      "transport", transport,
-                      NULL);
+  result = g_object_new (GIBBER_TYPE_R_MULTICAST_TRANSPORT,
+      "transport", transport, NULL);
 
-  gibber_transport_set_handler(GIBBER_TRANSPORT(transport),
+  gibber_transport_set_handler (GIBBER_TRANSPORT (transport),
       received_data, result);
 
   return result;
@@ -635,6 +639,7 @@ setup_joining_phase (GibberRMulticastTransport *self)
     {
       stop_send_attempt_join (self);
       g_source_remove (priv->joining_timeout);
+      priv->joining_timeout = 0;
       /* every member with state >= MEMBER_STATE_ATTEMPT_JOIN_REPEAT, will be
        * in our join */
       g_assert (priv->send_join == NULL);
@@ -659,7 +664,8 @@ setup_joining_phase (GibberRMulticastTransport *self)
 
   members = member_list_to_str (self);
   DEBUG ("New join state: %s", members);
-  g_free(members);
+
+  g_free (members);
 }
 
 static void
@@ -712,7 +718,7 @@ start_joining_phase (GibberRMulticastTransport *self)
       sender = gibber_r_multicast_causal_transport_get_sender (priv->transport,
         g_array_index (priv->pending_failures, guint32, i));
 
-      gibber_r_multicast_sender_set_failed(sender);
+      gibber_r_multicast_sender_set_failed (sender);
     }
 
   if (priv->pending_failures->len > 0)
@@ -1077,7 +1083,7 @@ send_failure_packet (GibberRMulticastTransport *self)
         g_array_index (priv->pending_failures, guint32, i));
 
       if (sender != NULL)
-        gibber_r_multicast_sender_set_failed(sender);
+        gibber_r_multicast_sender_set_failed (sender);
     }
 
   priv->pending_failures =
@@ -1102,7 +1108,7 @@ find_unfailed_member (gpointer key, gpointer value, gpointer user_data)
         return FALSE;
     }
 
-  DEBUG ("%x didn't fail %x on time", info->id, *id);
+  DEBUG ("At least %x didn't fail %x", info->id, *id);
 
   return TRUE;
 }
@@ -1214,6 +1220,8 @@ fail_member_timeout_cb (gpointer user_data)
   while ((tinfo = g_hash_table_find (priv->members, find_unfailed_member,
       &info->id)) != NULL)
     {
+      DEBUG ("Failing %x because it didn't fail %x in time", tinfo->id,
+          info->id);
       fail_member (self, NULL, tinfo->id);
     }
 
@@ -1277,7 +1285,7 @@ handle_failure_packet (GibberRMulticastTransport *self,
   info = member_get_info (self, packet->sender);
   for (i = 0; i < packet->data.failure.failures->len; i++)
     {
-      guint32 id = g_array_index(packet->data.failure.failures, guint32, i);
+      guint32 id = g_array_index (packet->data.failure.failures, guint32, i);
 
       DEBUG ("%x failed %x", packet->sender, id);
       fail_member (self, info, id);
@@ -1346,6 +1354,7 @@ check_join (GibberRMulticastTransport *self, GibberRMulticastPacket *packet)
        * the failures.. Should be handled earlier. but reset anyways */
       DEBUG ("Join doesn't contain us, shouldn't happen, reset to be sure :(");
       gibber_r_multicast_transport_reset (self);
+      return JOIN_FAILED;
     }
 
   seen = 0;
@@ -1413,7 +1422,12 @@ check_join_agreement (GibberRMulticastTransport *self)
       if (info == NULL)
         continue;
 
-      if (info->state >= MEMBER_STATE_FAILING)
+      /* send_join only contains members we didn't consider as failures at the
+       * time of the join message. The failure process for those has to be
+       * completely done before we can discard them, as it might have send out
+       * a JOIN we just hadn't received just yet.. Only after their failing
+       * has finished the state gets set to MEMBER_STATE_INSTANT_FAILURE  */
+      if (info->state >= MEMBER_STATE_INSTANT_FAILURE)
         continue;
 
       if (!info->agreed_join)
@@ -1421,8 +1435,8 @@ check_join_agreement (GibberRMulticastTransport *self)
     }
 
   DEBUG ("---Finished joining phase!!!!---");
-  new = g_array_new (FALSE, FALSE, sizeof(gchar *));
-  lost = g_array_new (FALSE, FALSE, sizeof(gchar *));
+  new = g_array_new (FALSE, FALSE, sizeof (gchar *));
+  lost = g_array_new (FALSE, FALSE, sizeof (gchar *));
 
   for (i = 0 ; i < priv->send_join_failures->len; i++)
     {
@@ -1660,18 +1674,18 @@ sender_failed_cb (GibberRMulticastCausalTransport *ctransport,
 }
 
 gboolean
-gibber_r_multicast_transport_connect(GibberRMulticastTransport *transport,
+gibber_r_multicast_transport_connect (GibberRMulticastTransport *transport,
     GError **error)
 {
   GibberRMulticastTransportPrivate *priv =
     GIBBER_R_MULTICAST_TRANSPORT_GET_PRIVATE (transport);
 
-  g_assert (gibber_transport_get_state (GIBBER_TRANSPORT(priv->transport)) ==
+  g_assert (gibber_transport_get_state (GIBBER_TRANSPORT (priv->transport)) ==
       GIBBER_TRANSPORT_CONNECTED);
-  g_assert (gibber_transport_get_state (GIBBER_TRANSPORT(transport)) !=
+  g_assert (gibber_transport_get_state (GIBBER_TRANSPORT (transport)) !=
       GIBBER_TRANSPORT_CONNECTED);
 
-  gibber_transport_set_state(GIBBER_TRANSPORT(transport),
+  gibber_transport_set_state (GIBBER_TRANSPORT(transport),
          GIBBER_TRANSPORT_CONNECTED);
 
   priv->state = STATE_NORMAL;
@@ -1689,44 +1703,47 @@ gibber_r_multicast_transport_connect(GibberRMulticastTransport *transport,
 }
 
 gboolean
-gibber_r_multicast_transport_send(GibberRMulticastTransport *transport,
-                                  guint16 stream_id,
-                                  const guint8 *data,
-                                  gsize size,
-                                  GError **error) {
+gibber_r_multicast_transport_send (GibberRMulticastTransport *transport,
+    guint16 stream_id, const guint8 *data, gsize size, GError **error)
+{
   GibberRMulticastTransport *self = GIBBER_R_MULTICAST_TRANSPORT (transport);
   GibberRMulticastTransportPrivate *priv =
     GIBBER_R_MULTICAST_TRANSPORT_GET_PRIVATE (self);
 
-  return gibber_r_multicast_causal_transport_send(priv->transport,
+  if (priv->state == STATE_RESETTING)
+    return TRUE;
+
+  return gibber_r_multicast_causal_transport_send (priv->transport,
      stream_id, data, size, error);
 }
 
 static gboolean
-gibber_r_multicast_transport_do_send(GibberTransport *transport,
-                                     const guint8 *data,
-                                     gsize size,
-                                     GError **error)
+gibber_r_multicast_transport_do_send (GibberTransport *transport,
+    const guint8 *data, gsize size, GError **error)
 {
   GibberRMulticastTransportPrivate *priv =
     GIBBER_R_MULTICAST_TRANSPORT_GET_PRIVATE (transport);
 
-  return gibber_transport_send(GIBBER_TRANSPORT(priv->transport),
+  if (priv->state == STATE_RESETTING)
+    return TRUE;
+
+  return gibber_transport_send (GIBBER_TRANSPORT (priv->transport),
       data, size, error);
 }
 
 static void
-transport_disconnected(GibberTransport *transport,
+transport_disconnected (GibberTransport *transport,
   gpointer user_data)
 {
   GibberRMulticastTransport *self = GIBBER_R_MULTICAST_TRANSPORT (user_data);
 
-  gibber_transport_set_state(GIBBER_TRANSPORT(self),
+  gibber_transport_set_state (GIBBER_TRANSPORT (self),
                              GIBBER_TRANSPORT_DISCONNECTED);
 }
 
 static void
-gibber_r_multicast_transport_disconnect(GibberTransport *transport) {
+gibber_r_multicast_transport_disconnect (GibberTransport *transport)
+{
   GibberRMulticastTransport *self = GIBBER_R_MULTICAST_TRANSPORT (transport);
   GibberRMulticastTransportPrivate *priv =
     GIBBER_R_MULTICAST_TRANSPORT_GET_PRIVATE (self);
@@ -1740,10 +1757,10 @@ gibber_r_multicast_transport_disconnect(GibberTransport *transport) {
   /* Remove all the state we had. This will also stop all running timers */
   gibber_r_multicast_transport_flush_state (self);
 
-  gibber_transport_set_state(GIBBER_TRANSPORT(self),
-                             GIBBER_TRANSPORT_DISCONNECTING);
+  gibber_transport_set_state (GIBBER_TRANSPORT (self),
+      GIBBER_TRANSPORT_DISCONNECTING);
 
   g_signal_connect (priv->transport, "disconnected",
       G_CALLBACK(transport_disconnected), self);
-  gibber_transport_disconnect(GIBBER_TRANSPORT(priv->transport));
+  gibber_transport_disconnect (GIBBER_TRANSPORT (priv->transport));
 }
