@@ -67,6 +67,8 @@ GDebugKey keys[] = {
   { "tubes",          DEBUG_TUBES },
   { "xmpp-connection-manager",  DEBUG_XCM },
   { "bytestream-manager",       DEBUG_BYTESTREAM_MGR },
+  { "discovery",      DEBUG_DISCO },
+  { "olpc-activity",      DEBUG_OLPC_ACTIVITY },
   { "all",            ~0 },
   { 0, },
 };
@@ -80,11 +82,7 @@ void debug_set_flags_from_env ()
 
   flags_string = g_getenv ("SALUT_DEBUG");
 
-#ifdef HAVE_TP_DEBUG_SET_FLAGS
-      tp_debug_set_flags (flags_string);
-#else
-      tp_debug_set_flags_from_string (flags_string);
-#endif
+  tp_debug_set_flags (flags_string);
 
   if (flags_string) {
     debug_set_flags (g_parse_debug_string (flags_string, keys, nkeys));
