@@ -32,6 +32,8 @@ typedef enum
   DEBUG_SELF           = 1 << 13,
   DEBUG_TUBES          = 1 << 14,
   DEBUG_XCM            = 1 << 15,
+  DEBUG_DISCOVERY      = 1 << 16,
+  DEBUG_OLPC_ACTIVITY  = 1 << 17,
 } DebugFlags;
 
 void debug_set_flags_from_env ();
@@ -43,7 +45,7 @@ void debug (DebugFlags flag, const gchar *format, ...)
 #ifdef DEBUG_FLAG
 
 #define DEBUG(format, ...) \
-  debug(DEBUG_FLAG, "%s: " format, G_STRFUNC, ##__VA_ARGS__)
+  debug (DEBUG_FLAG, "%s: " format, G_STRFUNC, ##__VA_ARGS__)
 
 #define DEBUGGING debug_flag_is_set(DEBUG_FLAG)
 
