@@ -42,7 +42,6 @@
 #include <telepathy-glib/util.h>
 
 #include <gibber/gibber-muc-connection.h>
-#include <avahi-gobject/ga-entry-group.h>
 
 #include "salut-connection.h"
 #include "salut-self.h"
@@ -51,10 +50,8 @@
 
 #include "text-helper.h"
 
-static void
-channel_iface_init(gpointer g_iface, gpointer iface_data);
-static void
-text_iface_init(gpointer g_iface, gpointer iface_data);
+static void channel_iface_init (gpointer g_iface, gpointer iface_data);
+static void text_iface_init (gpointer g_iface, gpointer iface_data);
 
 G_DEFINE_TYPE_WITH_CODE(SalutMucChannel, salut_muc_channel, G_TYPE_OBJECT,
     G_IMPLEMENT_INTERFACE(TP_TYPE_SVC_CHANNEL, channel_iface_init);
@@ -84,7 +81,6 @@ enum
   PROP_MUC_CONNECTION,
   PROP_CONNECTION,
   PROP_NAME,
-  PROP_CLIENT,
   PROP_CREATOR,
   PROP_XMPP_CONNECTION_MANAGER,
   LAST_PROPERTY
@@ -104,9 +100,6 @@ struct _SalutMucChannelPrivate
   GibberMucConnection *muc_connection;
   gchar *muc_name;
   gboolean connected;
-  GaClient *client;
-  GaEntryGroup *muc_group;
-  GaEntryGroupService *service;
   gboolean creator;
   guint timeout;
   /* (gchar *) -> (SalutContact *) */
@@ -117,19 +110,19 @@ struct _SalutMucChannelPrivate
 #define SALUT_MUC_CHANNEL_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), SALUT_TYPE_MUC_CHANNEL, SalutMucChannelPrivate))
 
 /* Callback functions */
-static gboolean salut_muc_channel_send_stanza(SalutMucChannel *self,
-                                              guint type,
-                                              const gchar *text,
-                                              GibberXmppStanza *stanza,
-                                              GError **error);
-static void salut_muc_channel_received_stanza(GibberMucConnection *conn,
-                                              const gchar *sender,
-                                              GibberXmppStanza *stanza,
-                                              gpointer user_data);
+static gboolean salut_muc_channel_send_stanza (SalutMucChannel *self,
+                                               guint type,
+                                               const gchar *text,
+                                               GibberXmppStanza *stanza,
+                                               GError **error);
+static void salut_muc_channel_received_stanza (GibberMucConnection *conn,
+                                               const gchar *sender,
+                                               GibberXmppStanza *stanza,
+                                               gpointer user_data);
 static gboolean
-salut_muc_channel_connect(SalutMucChannel *channel, GError **error);
-static void salut_muc_channel_disconnected(GibberTransport *transport,
-                                             gpointer user_data);
+salut_muc_channel_connect (SalutMucChannel *channel, GError **error);
+static void salut_muc_channel_disconnected (GibberTransport *transport,
+                                            gpointer user_data);
 
 static void
 salut_muc_channel_get_property (GObject    *object,
@@ -145,7 +138,7 @@ salut_muc_channel_get_property (GObject    *object,
       g_value_set_string (value, priv->object_path);
       break;
     case PROP_NAME:
-      g_value_set_string(value, priv->muc_name);
+      g_value_set_string (value, priv->muc_name);
       break;
     case PROP_CHANNEL_TYPE:
       g_value_set_static_string (value, TP_IFACE_CHANNEL_TYPE_TEXT);
@@ -157,14 +150,11 @@ salut_muc_channel_get_property (GObject    *object,
       g_value_set_uint (value, priv->handle);
       break;
     case PROP_CONNECTION:
-      g_value_set_object (value, priv->connection);
+      g_value_set_object (value, chan->connection);
       break;
     case PROP_MUC_CONNECTION:
       g_value_set_object (value, priv->muc_connection);
       break;
-    case PROP_CLIENT:
-      g_value_set_object (value, priv->client);
-      break;
     case PROP_CREATOR:
       g_value_set_boolean (value, priv->creator);
       break;
@@ -200,30 +190,26 @@ salut_muc_channel_set_property (GObject     *object,
       priv->handle = g_value_get_uint (value);
       break;
     case PROP_CONNECTION:
-      priv->connection = g_value_get_object (value);
+      chan->connection = g_value_get_object (value);
       break;
     case PROP_MUC_CONNECTION:
       priv->muc_connection = g_value_get_object (value);
       break;
     case PROP_HANDLE_TYPE:
-      g_assert(g_value_get_uint(value) == 0
-               || g_value_get_uint(value) == TP_HANDLE_TYPE_ROOM);
+      g_assert (g_value_get_uint (value) == 0
+               || g_value_get_uint (value) == TP_HANDLE_TYPE_ROOM);
       break;
     case PROP_CHANNEL_TYPE:
-      tmp = g_value_get_string(value);
-      g_assert(tmp == NULL
-               || !tp_strdiff(g_value_get_string(value),
-                       TP_IFACE_CHANNEL_TYPE_TEXT));
-      break;
-    case PROP_CLIENT:
-      priv->client = g_value_get_object (value);
+      tmp = g_value_get_string (value);
+      g_assert (tmp == NULL
+          || !tp_strdiff (g_value_get_string (value),
+              TP_IFACE_CHANNEL_TYPE_TEXT));
       break;
     case PROP_CREATOR:
       priv->creator = g_value_get_boolean (value);
       break;
    case PROP_XMPP_CONNECTION_MANAGER:
       priv->xmpp_connection_manager = g_value_get_object (value);
-      g_object_ref (priv->xmpp_connection_manager);
       break;
     default:
       G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
@@ -235,7 +221,7 @@ static void
 salut_muc_channel_add_self_to_members (SalutMucChannel *self)
 {
   SalutMucChannelPrivate *priv = SALUT_MUC_CHANNEL_GET_PRIVATE (self);
-  TpBaseConnection *base_connection = TP_BASE_CONNECTION (priv->connection);
+  TpBaseConnection *base_connection = TP_BASE_CONNECTION (self->connection);
   TpIntSet *empty;
   TpIntSet *add;
 
@@ -267,6 +253,8 @@ connected_timeout_cb (gpointer user_data)
   SalutMucChannel *self = SALUT_MUC_CHANNEL (user_data);
   SalutMucChannelPrivate *priv = SALUT_MUC_CHANNEL_GET_PRIVATE (self);
 
+  DEBUG ("Didn't receive muc senders. Timeout expired, "
+      "adding myself as member anyway");
   salut_muc_channel_add_self_to_members (self);
   priv->timeout = 0;
 
@@ -280,50 +268,59 @@ muc_connection_connected_cb (GibberMucConnection *connection,
   SalutMucChannelPrivate *priv = SALUT_MUC_CHANNEL_GET_PRIVATE (self);
 
   if (priv->creator)
-    salut_muc_channel_add_self_to_members (self);
+    {
+      DEBUG ("I created this muc. Adding myself as member now");
+      salut_muc_channel_add_self_to_members (self);
+    }
   else
-    priv->timeout = g_timeout_add (CONNECTED_TIMEOUT, connected_timeout_cb,
-        self);
+    {
+      DEBUG ("I didn't create this muc. Waiting for senders before adding "
+          "myself as member");
+      priv->timeout = g_timeout_add (CONNECTED_TIMEOUT, connected_timeout_cb,
+          self);
+    }
 
   salut_muc_channel_publish_service  (self);
 }
 
 static GObject *
 salut_muc_channel_constructor (GType type, guint n_props,
-                              GObjectConstructParam *props) {
+    GObjectConstructParam *props)
+{
   GObject *obj;
   DBusGConnection *bus;
+  SalutMucChannel *self;
   SalutMucChannelPrivate *priv;
   TpBaseConnection *base_conn;
   TpHandleRepoIface *handle_repo;
   TpHandleRepoIface *contact_repo;
 
   /* Parent constructor chain */
-  obj = G_OBJECT_CLASS(salut_muc_channel_parent_class)->
-        constructor(type, n_props, props);
+  obj = G_OBJECT_CLASS (salut_muc_channel_parent_class)->
+        constructor (type, n_props, props);
 
-  priv = SALUT_MUC_CHANNEL_GET_PRIVATE (SALUT_MUC_CHANNEL (obj));
+  self = SALUT_MUC_CHANNEL (obj);
+  priv = SALUT_MUC_CHANNEL_GET_PRIVATE (self);
 
   /* Ref our handle */
-  base_conn = TP_BASE_CONNECTION(priv->connection);
+  base_conn = TP_BASE_CONNECTION (self->connection);
 
-  handle_repo = tp_base_connection_get_handles(base_conn,
+  handle_repo = tp_base_connection_get_handles (base_conn,
       TP_HANDLE_TYPE_ROOM);
 
-  tp_handle_ref(handle_repo, priv->handle);
+  tp_handle_ref (handle_repo, priv->handle);
 
   /* Text mixin initialisation */
-  contact_repo = tp_base_connection_get_handles(base_conn,
-                                                TP_HANDLE_TYPE_CONTACT);
-  tp_text_mixin_init(obj, G_STRUCT_OFFSET(SalutMucChannel, text),
-                     contact_repo);
+  contact_repo = tp_base_connection_get_handles (base_conn,
+      TP_HANDLE_TYPE_CONTACT);
+  tp_text_mixin_init (obj, G_STRUCT_OFFSET (SalutMucChannel, text),
+      contact_repo);
 
-  tp_text_mixin_set_message_types(obj,
-                               TP_CHANNEL_TEXT_MESSAGE_TYPE_NORMAL,
-                               TP_CHANNEL_TEXT_MESSAGE_TYPE_ACTION,
-                               G_MAXUINT);
+  tp_text_mixin_set_message_types (obj,
+      TP_CHANNEL_TEXT_MESSAGE_TYPE_NORMAL, TP_CHANNEL_TEXT_MESSAGE_TYPE_ACTION,
+      TP_CHANNEL_TEXT_MESSAGE_TYPE_NOTICE, G_MAXUINT);
 
-  g_object_get (priv->connection, "self", &(priv->self), NULL);
+  g_object_get (self->connection, "self", &(priv->self), NULL);
   g_object_unref (priv->self);
   g_assert (priv->self != NULL);
 
@@ -333,20 +330,22 @@ salut_muc_channel_constructor (GType type, guint n_props,
   g_signal_connect (priv->muc_connection, "connected",
       G_CALLBACK (muc_connection_connected_cb), obj);
 
-  g_object_get (priv->connection,
+  g_object_get (self->connection,
       "muc-manager", &(priv->muc_manager),
       NULL);
   g_assert (priv->muc_manager != NULL);
 
+  /* no need to keep a ref on the muc manager as it keeps a ref on us */
+  g_object_unref (priv->muc_manager);
+
   /* Connect to the bus */
   bus = tp_get_bus ();
-  dbus_g_connection_register_g_object(bus, priv->object_path, obj);
+  dbus_g_connection_register_g_object (bus, priv->object_path, obj);
 
-  tp_group_mixin_init(obj,
-      G_STRUCT_OFFSET(SalutMucChannel, group),
+  tp_group_mixin_init (obj, G_STRUCT_OFFSET(SalutMucChannel, group),
       contact_repo, base_conn->self_handle);
 
-  tp_group_mixin_change_flags(obj,
+  tp_group_mixin_change_flags (obj,
        TP_CHANNEL_GROUP_FLAG_CAN_ADD|TP_CHANNEL_GROUP_FLAG_MESSAGE_ADD, 0);
 
   return obj;
@@ -358,11 +357,9 @@ salut_muc_channel_init (SalutMucChannel *self)
   SalutMucChannelPrivate *priv = SALUT_MUC_CHANNEL_GET_PRIVATE (self);
   /* allocate any data required by the object here */
   priv->object_path = NULL;
-  priv->connection = NULL;
+  self->connection = NULL;
   priv->xmpp_connection_manager = NULL;
   priv->muc_name = NULL;
-  priv->client = NULL;
-  priv->service = NULL;
   priv->timeout = 0;
   priv->senders = g_hash_table_new_full (g_str_hash, g_str_equal,
       NULL, (GDestroyNotify) g_object_unref);
@@ -372,9 +369,7 @@ static void salut_muc_channel_dispose (GObject *object);
 static void salut_muc_channel_finalize (GObject *object);
 
 static void
-invitation_append_parameter (gpointer key,
-                             gpointer value,
-                             gpointer data)
+invitation_append_parameter (gpointer key, gpointer value, gpointer data)
 {
   GibberXmppNode *node = (GibberXmppNode *) data;
   gibber_xmpp_node_add_child_with_content (node, (gchar *) key,
@@ -382,24 +377,23 @@ invitation_append_parameter (gpointer key,
 }
 
 static GibberXmppStanza *
-create_invitation (SalutMucChannel *self,
-                   TpHandle handle,
-                   const gchar *message)
+create_invitation (SalutMucChannel *self, TpHandle handle,
+    const gchar *message)
 {
   SalutMucChannelPrivate *priv = SALUT_MUC_CHANNEL_GET_PRIVATE (self);
-  TpBaseConnection *base_connection = TP_BASE_CONNECTION(priv->connection);
+  TpBaseConnection *base_connection = TP_BASE_CONNECTION(self->connection);
   TpHandleRepoIface *contact_repo =
-      tp_base_connection_get_handles(base_connection, TP_HANDLE_TYPE_CONTACT);
+      tp_base_connection_get_handles (base_connection, TP_HANDLE_TYPE_CONTACT);
   TpHandleRepoIface *room_repo =
-      tp_base_connection_get_handles(base_connection, TP_HANDLE_TYPE_ROOM);
+      tp_base_connection_get_handles (base_connection, TP_HANDLE_TYPE_ROOM);
   GibberXmppStanza *msg;
   GibberXmppNode *invite_node;
 
-  const gchar *name = tp_handle_inspect(contact_repo, handle);
+  const gchar *name = tp_handle_inspect (contact_repo, handle);
 
   msg = gibber_xmpp_stanza_build (GIBBER_STANZA_TYPE_MESSAGE,
       GIBBER_STANZA_SUB_TYPE_NORMAL,
-      priv->connection->name, name,
+      self->connection->name, name,
       GIBBER_NODE, "body",
         GIBBER_NODE_TEXT, "You got a Clique chatroom invitation",
       GIBBER_NODE_END,
@@ -414,8 +408,7 @@ create_invitation (SalutMucChannel *self,
 
   if (message != NULL && *message != '\0')
     {
-      gibber_xmpp_node_add_child_with_content(invite_node, "reason",
-          message);
+      gibber_xmpp_node_add_child_with_content (invite_node, "reason", message);
     }
 
   g_hash_table_foreach (
@@ -435,129 +428,9 @@ gboolean
 salut_muc_channel_publish_service (SalutMucChannel *self)
 {
   SalutMucChannelPrivate *priv = SALUT_MUC_CHANNEL_GET_PRIVATE (self);
-  AvahiStringList *txt_record = NULL;
-  GError *error = NULL;
-  const GHashTable *params;
-  const gchar *address, *port_str;
-  gchar *host = NULL;
-  guint16 port;
-  uint16_t dns_type;
-  size_t dns_payload_length;
-  AvahiAddress addr;
 
-  /* We are already announcing this muc group */
-  if (priv->muc_group != NULL)
-    return TRUE;
-
-  g_assert (priv->service == NULL);
-
-  /* We didn't connect to this group just yet */
-  if (priv->muc_connection->state != GIBBER_MUC_CONNECTION_CONNECTED)
-    {
-      DEBUG ("Not yet connected to this muc, not announcing");
-      return TRUE;
-    }
-
-  priv->muc_group = ga_entry_group_new ();
-
-  if (!ga_entry_group_attach (priv->muc_group, priv->client, &error))
-    {
-      DEBUG ("entry group attach failed: %s", error->message);
-      goto publish_service_error;
-    }
-
-  params = gibber_muc_connection_get_parameters (priv->muc_connection);
-  address = g_hash_table_lookup ((GHashTable *) params, "address");
-  if (address == NULL)
-    {
-      DEBUG ("can't find connection address");
-      goto publish_service_error;
-    }
-  port_str = g_hash_table_lookup ((GHashTable *) params, "port");
-  if (port_str == NULL)
-    {
-      DEBUG ("can't find connection port");
-      goto publish_service_error;
-    }
-
-  if (avahi_address_parse (address, AVAHI_PROTO_UNSPEC, &addr) == NULL)
-    {
-      DEBUG ("Can't convert address \"%s\" to AvahiAddress", address);
-      goto publish_service_error;
-    }
-
-  switch (addr.proto)
-    {
-    case AVAHI_PROTO_INET:
-      dns_type = AVAHI_DNS_TYPE_A;
-      dns_payload_length = sizeof (AvahiIPv4Address);
-      break;
-    case AVAHI_PROTO_INET6:
-      dns_type = AVAHI_DNS_TYPE_AAAA;
-      dns_payload_length = sizeof (AvahiIPv6Address);
-      break;
-    default:
-      DEBUG ("Don't know how to convert AvahiProtocol 0x%x to DNS record",
-          addr.proto);
-      goto publish_service_error;
-    }
-
-  host = g_strdup_printf ("%s." SALUT_DNSSD_CLIQUE ".local", priv->muc_name);
-
-  /* Add the record */
-  if (!ga_entry_group_add_record_full (priv->muc_group,
-        AVAHI_IF_UNSPEC, addr.proto, 0,
-        host, AVAHI_DNS_CLASS_IN, dns_type, AVAHI_DEFAULT_TTL_HOST_NAME,
-        &(addr.data.data), dns_payload_length, &error))
-    {
-      DEBUG ("add A/AAAA record failed: %s", error->message);
-      goto publish_service_error;
-    }
-
-  port = atoi (port_str);
-
-  txt_record = avahi_string_list_new ("txtvers=0", NULL);
-
-  /* We shouldn't add the service but manually create the SRV record so
-   * we'll be able to allow multiple announcers */
-  priv->service = ga_entry_group_add_service_full_strlist (
-      priv->muc_group, AVAHI_IF_UNSPEC, addr.proto, 0, priv->muc_name,
-      SALUT_DNSSD_CLIQUE, NULL, host, port, &error, txt_record);
-  if (priv->service == NULL)
-    {
-      DEBUG ("add service failed: %s", error->message);
-      goto publish_service_error;
-    }
-
-  if (!ga_entry_group_commit (priv->muc_group, &error))
-    {
-      DEBUG ("entry group commit failed: %s", error->message);
-      goto publish_service_error;
-    }
-
-  DEBUG ("service created: %s %s %d", priv->muc_name, host, port);
-  avahi_string_list_free (txt_record);
-  g_free (host);
-  return TRUE;
-
-publish_service_error:
-  if (priv->muc_group != NULL)
-    {
-      g_object_unref (priv->muc_group);
-      priv->muc_group = NULL;
-    }
-
-  priv->service = NULL;
-
-  if (txt_record != NULL)
-    avahi_string_list_free (txt_record);
-
-  if (host != NULL)
-    g_free (host);
-
-  if (error != NULL)
-    g_error_free (error);
-  return FALSE;
+  return SALUT_MUC_CHANNEL_GET_CLASS (self)->publish_service (self,
+      priv->muc_connection, priv->muc_name);
 }
 
 struct
@@ -615,8 +488,7 @@ xmpp_connection_manager_connection_failed_cb (SalutXmppConnectionManager *mgr,
                                               gpointer user_data)
 {
   SalutMucChannel *self = SALUT_MUC_CHANNEL (user_data);
-  SalutMucChannelPrivate *priv = SALUT_MUC_CHANNEL_GET_PRIVATE (self);
-  TpBaseConnection *base_connection = TP_BASE_CONNECTION (priv->connection);
+  TpBaseConnection *base_connection = TP_BASE_CONNECTION (self->connection);
   TpHandleRepoIface *contact_repo =
       tp_base_connection_get_handles (base_connection, TP_HANDLE_TYPE_CONTACT);
   struct pending_connection_for_invite_data *data =
@@ -665,7 +537,7 @@ salut_muc_channel_send_invitation (SalutMucChannel *self,
   struct pending_connection_for_invite_data *data;
   GibberXmppConnection *connection = NULL;
 
-  g_object_get (G_OBJECT (priv->connection), "contact-manager",
+  g_object_get (G_OBJECT (self->connection), "contact-manager",
       &contact_manager, NULL);
   g_assert (contact_manager != NULL);
 
@@ -715,15 +587,17 @@ salut_muc_channel_send_invitation (SalutMucChannel *self,
   return TRUE;
 }
 
-static gboolean
-muc_channel_add_member (GObject *iface,
-                        TpHandle handle,
-                        const gchar *message,
-                        GError **error)
+/* FIXME: This is an ugly workaround. See fd.o #15092
+ * We shouldn't export this function */
+gboolean
+salut_muc_channel_add_member (GObject *iface,
+                              TpHandle handle,
+                              const gchar *message,
+                              GError **error)
 {
   SalutMucChannel *self = SALUT_MUC_CHANNEL(iface);
   SalutMucChannelPrivate *priv = SALUT_MUC_CHANNEL_GET_PRIVATE (self);
-  TpBaseConnection *base_connection = TP_BASE_CONNECTION (priv->connection);
+  TpBaseConnection *base_connection = TP_BASE_CONNECTION (self->connection);
   TpIntSet *empty, *remote_pending;
 
   if (handle == base_connection->self_handle)
@@ -745,7 +619,7 @@ muc_channel_add_member (GObject *iface,
       tp_intset_add (add, handle);
       /* Add to members */
 
-      if (salut_muc_channel_connect(self, NULL))
+      if (salut_muc_channel_connect (self, NULL))
         {
           /* We are considered as remote-pending while the muc connection
            * is not connected */
@@ -840,19 +714,6 @@ salut_muc_channel_class_init (SalutMucChannelClass *salut_muc_channel_class) {
   g_object_class_install_property (object_class,
                                    PROP_CONNECTION, param_spec);
 
-  param_spec = g_param_spec_object (
-      "client",
-      "GaClient object",
-      "Salut Avahi client used with the"
-      " connection that owns this MUC channel",
-      GA_TYPE_CLIENT,
-      G_PARAM_CONSTRUCT_ONLY |
-      G_PARAM_READWRITE |
-      G_PARAM_STATIC_NICK |
-      G_PARAM_STATIC_BLURB);
-  g_object_class_install_property (object_class,
-      PROP_CLIENT, param_spec);
-
   param_spec = g_param_spec_object (
       "xmpp-connection-manager",
       "SalutXmppConnectionManager object",
@@ -895,12 +756,12 @@ salut_muc_channel_class_init (SalutMucChannelClass *salut_muc_channel_class) {
         g_cclosure_marshal_VOID__POINTER,
         G_TYPE_NONE, 1, G_TYPE_POINTER);
 
-  tp_text_mixin_class_init(object_class,
-                           G_STRUCT_OFFSET(SalutMucChannelClass, text_class));
+  tp_text_mixin_class_init (object_class,
+      G_STRUCT_OFFSET(SalutMucChannelClass, text_class));
 
-  tp_group_mixin_class_init(object_class,
-    G_STRUCT_OFFSET(SalutMucChannelClass, group_class),
-    muc_channel_add_member, NULL);
+  tp_group_mixin_class_init (object_class,
+      G_STRUCT_OFFSET(SalutMucChannelClass, group_class),
+      salut_muc_channel_add_member, NULL);
 }
 
 void
@@ -917,21 +778,10 @@ salut_muc_channel_dispose (GObject *object)
   g_signal_handlers_disconnect_matched (priv->muc_connection,
       G_SIGNAL_MATCH_DATA, 0, 0, NULL, NULL, self);
 
-  if (priv->muc_connection != NULL) {
-    g_object_unref(priv->muc_connection);
-    priv->muc_connection = NULL;
-  }
-
-  if (priv->xmpp_connection_manager != NULL)
+  if (priv->muc_connection != NULL)
     {
-      g_object_unref (priv->xmpp_connection_manager);
-      priv->xmpp_connection_manager = NULL;
-    }
-
-  if (priv->muc_group != NULL)
-    {
-      g_object_unref (priv->muc_group);
-      priv->muc_group = NULL;
+      g_object_unref (priv->muc_connection);
+      priv->muc_connection = NULL;
     }
 
   if (priv->timeout != 0)
@@ -946,12 +796,6 @@ salut_muc_channel_dispose (GObject *object)
       priv->senders = NULL;
     }
 
-  if (priv->muc_manager != NULL)
-    {
-      g_object_unref (priv->muc_manager);
-      priv->muc_manager = NULL;
-    }
-
   /* release any references held by the object here */
   if (G_OBJECT_CLASS (salut_muc_channel_parent_class)->dispose)
     G_OBJECT_CLASS (salut_muc_channel_parent_class)->dispose (object);
@@ -964,80 +808,84 @@ salut_muc_channel_finalize (GObject *object)
   SalutMucChannelPrivate *priv = SALUT_MUC_CHANNEL_GET_PRIVATE (self);
 
   /* free any data held directly by the object here */
-  g_free(priv->object_path);
+  g_free (priv->object_path);
   g_free (priv->muc_name);
 
-  tp_text_mixin_finalize(object);
-  tp_group_mixin_finalize(object);
+  tp_text_mixin_finalize (object);
+  tp_group_mixin_finalize (object);
 
   G_OBJECT_CLASS (salut_muc_channel_parent_class)->finalize (object);
 }
 
 gboolean
 salut_muc_channel_invited (SalutMucChannel *self, TpHandle inviter,
-                          const gchar *stanza, GError **error) {
-  SalutMucChannelPrivate *priv = SALUT_MUC_CHANNEL_GET_PRIVATE(self);
-  TpBaseConnection *base_connection = TP_BASE_CONNECTION(priv->connection);
+                          const gchar *stanza, GError **error)
+{
+  SalutMucChannelPrivate *priv = SALUT_MUC_CHANNEL_GET_PRIVATE (self);
+  TpBaseConnection *base_connection = TP_BASE_CONNECTION (self->connection);
   TpHandleRepoIface *contact_repo =
-      tp_base_connection_get_handles(base_connection, TP_HANDLE_TYPE_CONTACT);
+      tp_base_connection_get_handles (base_connection, TP_HANDLE_TYPE_CONTACT);
   TpHandleRepoIface *room_repo =
-      tp_base_connection_get_handles(base_connection, TP_HANDLE_TYPE_ROOM);
+      tp_base_connection_get_handles (base_connection, TP_HANDLE_TYPE_ROOM);
   gboolean ret = TRUE;
 
   /* Got invited to this muc channel */
-  DEBUG("Got an invitation to %s from %s",
-    tp_handle_inspect(room_repo, priv->handle),
-    tp_handle_inspect(contact_repo, inviter)
-    );
+  DEBUG ("Got an invitation to %s from %s",
+      tp_handle_inspect (room_repo, priv->handle),
+        tp_handle_inspect (contact_repo, inviter));
 
   /* If we are already a member, no further actions are needed */
-  if (tp_handle_set_is_member(self->group.members,
-                              base_connection->self_handle)) {
+  if (tp_handle_set_is_member (self->group.members,
+      base_connection->self_handle)) {
     return TRUE;
   }
 
-  if (inviter == base_connection->self_handle) {
-    /* Invited ourselves, go straight to members */
-    gboolean r;
-    GArray *members =  g_array_sized_new (FALSE, FALSE, sizeof(TpHandle), 1);
-    g_array_append_val(members, base_connection->self_handle);
-    r = tp_group_mixin_add_members(G_OBJECT(self), members, "", error);
-    g_assert(r);
-    g_array_free(members, TRUE);
-  } else {
-    TpIntSet *empty = tp_intset_new();
-    TpIntSet *local_pending = tp_intset_new();
+  if (inviter == base_connection->self_handle)
+    {
+      /* Invited ourselves, go straight to members */
+      gboolean r;
+      GArray *members = g_array_sized_new (FALSE, FALSE, sizeof (TpHandle), 1);
+      g_array_append_val (members, base_connection->self_handle);
+      r = tp_group_mixin_add_members (G_OBJECT (self), members, "", error);
+      g_assert (r);
+      g_array_free (members, TRUE);
+    }
+  else
+    {
+      TpIntSet *empty = tp_intset_new ();
+      TpIntSet *local_pending = tp_intset_new ();
 
-    g_assert(stanza != NULL);
+      g_assert (stanza != NULL);
+
+      tp_intset_add (local_pending, base_connection->self_handle);
+      tp_group_mixin_change_members (G_OBJECT(self), stanza,
+                                     empty, empty,
+                                     local_pending, empty,
+                                     inviter,
+                                     TP_CHANNEL_GROUP_CHANGE_REASON_INVITED);
+      tp_intset_destroy (local_pending);
+      tp_intset_destroy (empty);
+    }
 
-    tp_intset_add(local_pending, base_connection->self_handle);
-    tp_group_mixin_change_members(G_OBJECT(self), stanza,
-                                  empty, empty,
-                                  local_pending, empty,
-                                  inviter,
-                                  TP_CHANNEL_GROUP_CHANGE_REASON_INVITED);
-    tp_intset_destroy(local_pending);
-    tp_intset_destroy(empty);
-  }
   return ret;
 }
 
 /* Private functions */
 static gboolean
-salut_muc_channel_send_stanza(SalutMucChannel *self, guint type,
+salut_muc_channel_send_stanza (SalutMucChannel *self, guint type,
                               const gchar *text,
                               GibberXmppStanza *stanza,
                               GError **error)
 {
-  SalutMucChannelPrivate *priv = SALUT_MUC_CHANNEL_GET_PRIVATE(self);
+  SalutMucChannelPrivate *priv = SALUT_MUC_CHANNEL_GET_PRIVATE (self);
 
-  if (!gibber_muc_connection_send(priv->muc_connection, stanza, error)) {
-    tp_svc_channel_type_text_emit_send_error(self,
-       TP_CHANNEL_TEXT_SEND_ERROR_UNKNOWN, time(NULL), type, text);
+  if (!gibber_muc_connection_send (priv->muc_connection, stanza, error)) {
+    tp_svc_channel_type_text_emit_send_error (self,
+       TP_CHANNEL_TEXT_SEND_ERROR_UNKNOWN, time (NULL), type, text);
     return FALSE;
   }
 
-  tp_svc_channel_type_text_emit_sent(self, time(NULL), type, text);
+  tp_svc_channel_type_text_emit_sent (self, time (NULL), type, text);
   return TRUE;
 }
 
@@ -1053,7 +901,7 @@ salut_muc_channel_add_members (SalutMucChannel *self,
   empty = tp_intset_new ();
   changes = tp_intset_new ();
 
-  g_object_get (G_OBJECT (priv->connection), "contact-manager",
+  g_object_get (G_OBJECT (self->connection), "contact-manager",
       &contact_mgr, NULL);
   g_assert (contact_mgr != NULL);
 
@@ -1086,7 +934,7 @@ salut_muc_channel_remove_members (SalutMucChannel *self,
 {
   SalutMucChannelPrivate *priv = SALUT_MUC_CHANNEL_GET_PRIVATE (self);
   TpBaseConnection *base_connection =
-      (TpBaseConnection *) (priv->connection);
+      (TpBaseConnection *) (self->connection);
   TpHandleRepoIface *contact_repo = tp_base_connection_get_handles
       (base_connection, TP_HANDLE_TYPE_CONTACT);
   TpIntSet *empty, *changes;
@@ -1124,37 +972,39 @@ salut_muc_channel_remove_members (SalutMucChannel *self,
 }
 
 static void
-salut_muc_channel_received_stanza(GibberMucConnection *conn,
-                                  const gchar *sender,
-                                  GibberXmppStanza *stanza,
-                                  gpointer user_data) {
-  SalutMucChannel *self = SALUT_MUC_CHANNEL(user_data);
-  SalutMucChannelPrivate *priv = SALUT_MUC_CHANNEL_GET_PRIVATE(self);
-  TpBaseConnection *base_connection = TP_BASE_CONNECTION(priv->connection);
+salut_muc_channel_received_stanza (GibberMucConnection *conn,
+                                   const gchar *sender,
+                                   GibberXmppStanza *stanza,
+                                   gpointer user_data)
+{
+  SalutMucChannel *self = SALUT_MUC_CHANNEL (user_data);
+  SalutMucChannelPrivate *priv = SALUT_MUC_CHANNEL_GET_PRIVATE (self);
+  TpBaseConnection *base_connection = TP_BASE_CONNECTION (self->connection);
   TpHandleRepoIface *contact_repo =
-      tp_base_connection_get_handles(base_connection, TP_HANDLE_TYPE_CONTACT);
+      tp_base_connection_get_handles (base_connection, TP_HANDLE_TYPE_CONTACT);
 
   const gchar *from, *to, *body, *body_offset;
   TpChannelTextMessageType msgtype;
   TpHandle from_handle;
   GibberXmppNode *tubes_node;
 
-  to = gibber_xmpp_node_get_attribute(stanza->node, "to");
-  if (strcmp(to, priv->muc_name)) {
+  to = gibber_xmpp_node_get_attribute (stanza->node, "to");
+  if (strcmp (to, priv->muc_name)) {
     DEBUG("Stanza to another muc group, discarding");
     return;
   }
 
-  from_handle = tp_handle_lookup(contact_repo, sender, NULL, NULL);
-  if (from_handle == 0) {
-    /* FIXME, unknown contact.. Need some way to handle this safely,
-     * just adding the contact is somewhat scary */
-    DEBUG("Got stanza from unknown contact, discarding");
-    return;
-  }
+  from_handle = tp_handle_lookup (contact_repo, sender, NULL, NULL);
+  if (from_handle == 0)
+    {
+      /* FIXME, unknown contact.. Need some way to handle this safely,
+       * just adding the contact is somewhat scary */
+      DEBUG("Got stanza from unknown contact, discarding");
+      return;
+    }
 
 #ifdef ENABLE_OLPC
-  if (salut_connection_olpc_observe_muc_stanza (priv->connection, priv->handle,
+  if (salut_connection_olpc_observe_muc_stanza (self->connection, priv->handle,
         from_handle, stanza))
     return;
 #endif
@@ -1174,20 +1024,22 @@ salut_muc_channel_received_stanza(GibberMucConnection *conn,
       g_object_unref (tubes_chan);
     }
 
-  if (!text_helper_parse_incoming_message(stanza, &from, &msgtype,
-                                          &body, &body_offset)) {
-    DEBUG("Couldn't parse stanza");
-    return;
-  }
+  if (!text_helper_parse_incoming_message (stanza, &from, &msgtype,
+      &body, &body_offset))
+    {
+        DEBUG("Couldn't parse stanza");
+        return;
+    }
 
-  if (body == NULL) {
-    DEBUG("Message with an empty body");
-    return;
-  }
+  if (body == NULL)
+    {
+      DEBUG("Message with an empty body");
+      return;
+    }
 
   /* FIXME validate the from and the to */
-  tp_text_mixin_receive(G_OBJECT(self), msgtype, from_handle,
-      time(NULL), body_offset);
+  tp_text_mixin_receive (G_OBJECT (self), msgtype, from_handle,
+      time (NULL), body_offset);
 }
 
 static void
@@ -1196,19 +1048,22 @@ salut_muc_channel_new_senders (GibberMucConnection *connection,
                                gpointer user_data)
 {
   SalutMucChannel *self = SALUT_MUC_CHANNEL (user_data);
-  SalutMucChannelPrivate *priv = SALUT_MUC_CHANNEL_GET_PRIVATE (self);
-  TpBaseConnection *base_connection = TP_BASE_CONNECTION (priv->connection);
+  TpBaseConnection *base_connection = TP_BASE_CONNECTION (self->connection);
 
   salut_muc_channel_add_members (self, senders);
   if (!tp_handle_set_is_member (self->group.members,
       base_connection->self_handle))
-    salut_muc_channel_add_self_to_members (self);
+    {
+      DEBUG ("Got new senders. Adding myself as member");
+      salut_muc_channel_add_self_to_members (self);
+    }
 }
 
 static void
-salut_muc_channel_lost_senders(GibberMucConnection *connection,
-    GArray *senders, gpointer user_data) {
-  SalutMucChannel *self = SALUT_MUC_CHANNEL(user_data);
+salut_muc_channel_lost_senders (GibberMucConnection *connection,
+    GArray *senders, gpointer user_data)
+{
+  SalutMucChannel *self = SALUT_MUC_CHANNEL (user_data);
 
   salut_muc_channel_remove_members (self, senders);
 }
@@ -1235,9 +1090,9 @@ salut_muc_channel_connect (SalutMucChannel *channel,
 }
 
 static void
-salut_muc_channel_disconnected(GibberTransport *transport,
-                                             gpointer user_data) {
-  SalutMucChannel *self = SALUT_MUC_CHANNEL(user_data);
+salut_muc_channel_disconnected (GibberTransport *transport, gpointer user_data)
+{
+  SalutMucChannel *self = SALUT_MUC_CHANNEL (user_data);
   SalutMucChannelPrivate *priv = SALUT_MUC_CHANNEL_GET_PRIVATE (self);
 
   if (priv->timeout != 0)
@@ -1254,7 +1109,13 @@ salut_muc_channel_disconnected(GibberTransport *transport,
       g_signal_emit (self, signals[JOIN_ERROR], 0, &error);
     }
 
-  tp_svc_channel_emit_closed(self);
+  tp_svc_channel_emit_closed (self);
+}
+
+void
+salut_muc_channel_emit_closed (SalutMucChannel *self)
+{
+  tp_svc_channel_emit_closed (self);
 }
 
 /* channel interfaces */
@@ -1272,7 +1133,8 @@ salut_muc_channel_disconnected(GibberTransport *transport,
  */
 static void
 salut_muc_channel_get_interfaces (TpSvcChannel *iface,
-                                  DBusGMethodInvocation *context) {
+    DBusGMethodInvocation *context)
+{
   const char *interfaces[] = { TP_IFACE_CHANNEL_INTERFACE_GROUP,  NULL };
 
   tp_svc_channel_return_from_get_interfaces (context, interfaces);
@@ -1293,9 +1155,9 @@ salut_muc_channel_get_interfaces (TpSvcChannel *iface,
  */
 static void
 salut_muc_channel_get_handle (TpSvcChannel *iface,
-                              DBusGMethodInvocation *context)
+    DBusGMethodInvocation *context)
 {
-  SalutMucChannel *self = SALUT_MUC_CHANNEL(iface);
+  SalutMucChannel *self = SALUT_MUC_CHANNEL (iface);
   SalutMucChannelPrivate *priv = SALUT_MUC_CHANNEL_GET_PRIVATE (self);
 
   tp_svc_channel_return_from_get_handle (context, TP_HANDLE_TYPE_ROOM,
@@ -1315,8 +1177,9 @@ salut_muc_channel_get_handle (TpSvcChannel *iface,
  */
 static void
 salut_muc_channel_get_channel_type (TpSvcChannel *iface,
-                                   DBusGMethodInvocation *context) {
-  tp_svc_channel_return_from_get_channel_type(context,
+    DBusGMethodInvocation *context)
+{
+  tp_svc_channel_return_from_get_channel_type (context,
       TP_IFACE_CHANNEL_TYPE_TEXT);
 }
 
@@ -1333,25 +1196,27 @@ salut_muc_channel_get_channel_type (TpSvcChannel *iface,
  * Returns: TRUE if successful, FALSE if an error was thrown.
  */
 static void
-salut_muc_channel_close (TpSvcChannel *iface, DBusGMethodInvocation *context) {
-  SalutMucChannel *self = SALUT_MUC_CHANNEL(iface);
+salut_muc_channel_close (TpSvcChannel *iface, DBusGMethodInvocation *context)
+{
+  SalutMucChannel *self = SALUT_MUC_CHANNEL (iface);
   SalutMucChannelPrivate *priv = SALUT_MUC_CHANNEL_GET_PRIVATE (self);
 
-  gibber_muc_connection_disconnect(priv->muc_connection);
+  gibber_muc_connection_disconnect (priv->muc_connection);
 
-  tp_svc_channel_return_from_close(context);
+  tp_svc_channel_return_from_close (context);
 }
 
 static void
-channel_iface_init(gpointer g_iface, gpointer iface_data) {
+channel_iface_init (gpointer g_iface, gpointer iface_data)
+{
   TpSvcChannelClass *klass = (TpSvcChannelClass *)g_iface;
 
 #define IMPLEMENT(x) tp_svc_channel_implement_##x (\
     klass, salut_muc_channel_##x)
-  IMPLEMENT(close);
-  IMPLEMENT(get_channel_type);
-  IMPLEMENT(get_handle);
-  IMPLEMENT(get_interfaces);
+  IMPLEMENT (close);
+  IMPLEMENT (get_channel_type);
+  IMPLEMENT (get_handle);
+  IMPLEMENT (get_interfaces);
 #undef IMPLEMENT
 }
 
@@ -1375,35 +1240,46 @@ salut_muc_channel_send (TpSvcChannelTypeText *channel,
   SalutMucChannel *self = SALUT_MUC_CHANNEL(channel);
   SalutMucChannelPrivate *priv = SALUT_MUC_CHANNEL_GET_PRIVATE(self);
   GError *error = NULL;
+  GibberXmppStanza *stanza;
 
-  GibberXmppStanza *stanza =
-      text_helper_create_message_groupchat (priv->connection->name,
+  if (type > TP_CHANNEL_TEXT_MESSAGE_TYPE_NOTICE)
+    {
+      GError ierror = { TP_ERRORS, TP_ERROR_INVALID_ARGUMENT,
+        "Invalid message type" };
+
+      dbus_g_method_return_error (context, &ierror);
+
+      return;
+    }
+
+  stanza = text_helper_create_message_groupchat (self->connection->name,
           priv->muc_name, type, text, &error);
 
   if (stanza == NULL) {
-    dbus_g_method_return_error(context, error);
-    g_error_free(error);
+    dbus_g_method_return_error (context, error);
+    g_error_free (error);
     return;
   }
 
-  if (!salut_muc_channel_send_stanza(self, type, text, stanza, &error)) {
-    g_object_unref(G_OBJECT(stanza));
-    dbus_g_method_return_error(context, error);
-    g_error_free(error);
+  if (!salut_muc_channel_send_stanza (self, type, text, stanza, &error)) {
+    g_object_unref (G_OBJECT (stanza));
+    dbus_g_method_return_error (context, error);
+    g_error_free (error);
   }
 
-  g_object_unref(G_OBJECT(stanza));
-  tp_svc_channel_type_text_return_from_send(context);
+  g_object_unref (G_OBJECT (stanza));
+  tp_svc_channel_type_text_return_from_send (context);
 }
 
 static void
-text_iface_init(gpointer g_iface, gpointer iface_data) {
+text_iface_init (gpointer g_iface, gpointer iface_data)
+{
   TpSvcChannelTypeTextClass *klass = (TpSvcChannelTypeTextClass *)g_iface;
 
   tp_text_mixin_iface_init (g_iface, iface_data);
 #define IMPLEMENT(x) tp_svc_channel_type_text_implement_##x (\
     klass, salut_muc_channel_##x)
-  IMPLEMENT(send);
+  IMPLEMENT (send);
 #undef IMPLEMENT
 }
 
