@@ -23,12 +23,12 @@
 #include <glib-object.h>
 
 #include <gibber/gibber-bytestream-iface.h>
-#include <avahi-gobject/ga-client.h>
 
 #include <salut-connection.h>
 #include "salut-xmpp-connection-manager.h"
 #include "salut-muc-channel.h"
 #include "salut-tubes-channel.h"
+#include "salut-muc-channel.h"
 
 G_BEGIN_DECLS
 
@@ -37,17 +37,31 @@ typedef struct _SalutMucManagerClass SalutMucManagerClass;
 
 struct _SalutMucManagerClass {
     GObjectClass parent_class;
+
+    /* public abstract methods */
+    gboolean (*start) (SalutMucManager *self, GError **error);
+
+    /* private abstract methods */
+    gboolean (*find_muc_address) (SalutMucManager *self, const gchar *name,
+        gchar **address, guint16 *port);
+
+    GSList * (*get_rooms) (SalutMucManager *self);
+
+    SalutMucChannel * (*create_muc_channel) (SalutMucManager *self,
+        SalutConnection *connection, const gchar *path,
+        GibberMucConnection *muc_connection, TpHandle handle,
+        const gchar *name, gboolean creator, SalutXmppConnectionManager *xcm);
 };
 
 struct _SalutMucManager {
     GObject parent;
 };
 
-GType salut_muc_manager_get_type(void);
+GType salut_muc_manager_get_type (void);
 
 /* TYPE MACROS */
 #define SALUT_TYPE_MUC_MANAGER \
-  (salut_muc_manager_get_type())
+  (salut_muc_manager_get_type ())
 #define SALUT_MUC_MANAGER(obj) \
   (G_TYPE_CHECK_INSTANCE_CAST((obj), SALUT_TYPE_MUC_MANAGER, SalutMucManager))
 #define SALUT_MUC_MANAGER_CLASS(klass) \
@@ -59,13 +73,8 @@ GType salut_muc_manager_get_type(void);
 #define SALUT_MUC_MANAGER_GET_CLASS(obj) \
   (G_TYPE_INSTANCE_GET_CLASS ((obj), SALUT_TYPE_MUC_MANAGER, SalutMucManagerClass))
 
-SalutMucManager *
-salut_muc_manager_new (SalutConnection *connection,
-                       SalutXmppConnectionManager *xmpp_connection_manager);
-
 gboolean
-salut_muc_manager_start (SalutMucManager *muc_manager,
-    GaClient *client, GError **error);
+salut_muc_manager_start (SalutMucManager *muc_manager, GError **error);
 
 SalutMucChannel *
 salut_muc_manager_get_text_channel (SalutMucManager *muc_manager,
@@ -78,6 +87,14 @@ void salut_muc_manager_handle_si_stream_request (SalutMucManager *muc_manager,
 SalutTubesChannel * salut_muc_manager_ensure_tubes_channel (
     SalutMucManager *muc_manager, TpHandle handle);
 
+
+/* "protected" methods */
+void salut_muc_manager_room_discovered (SalutMucManager *muc_manager,
+    const gchar *room);
+
+void salut_muc_manager_room_removed (SalutMucManager *muc_manager,
+    const gchar *room);
+
 G_END_DECLS
 
 #endif /* #ifndef __SALUT_MUC_MANAGER_H__*/
