@@ -1,6 +1,6 @@
 /*
  * tube-stream.c - Source for SalutTubeStream
- * Copyright (C) 2007 Ltd.
+ * Copyright (C) 2007-2008 Collabora Ltd.
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -36,6 +36,7 @@
 #include <gibber/gibber-xmpp-stanza.h>
 #include <gibber/gibber-namespaces.h>
 #include <gibber/gibber-bytestream-iface.h>
+#include <gibber/gibber-bytestream-oob.h>
 #include <gibber/gibber-transport.h>
 #include <gibber/gibber-fd-transport.h>
 
@@ -135,7 +136,7 @@ struct _SalutTubeStreamPrivate
 };
 
 #define SALUT_TUBE_STREAM_GET_PRIVATE(obj) \
-    ((SalutTubeStreamPrivate *) obj->priv)
+    ((SalutTubeStreamPrivate *) ((SalutTubeStream *)obj)->priv)
 
 static void data_received_cb (GibberBytestreamIface *ibb, TpHandle sender,
     GString *data, gpointer user_data);
@@ -193,6 +194,51 @@ transport_disconnected_cb (GibberTransport *transport,
   gibber_bytestream_iface_close (bytestream, NULL);
 }
 
+static void
+remove_transport (SalutTubeStream *self,
+                  GibberTransport *transport)
+{
+  SalutTubeStreamPrivate *priv = SALUT_TUBE_STREAM_GET_PRIVATE (self);
+  GibberBytestreamIface *bytestream;
+
+  bytestream = g_hash_table_lookup (priv->transport_to_bytestream, transport);
+  g_assert (bytestream != NULL);
+
+  DEBUG ("disconnect and remove transport");
+  g_signal_handlers_disconnect_matched (transport, G_SIGNAL_MATCH_DATA,
+      0, 0, NULL, NULL, self);
+
+  gibber_transport_disconnect (transport);
+  g_hash_table_remove (priv->transport_to_bytestream, transport);
+
+  g_hash_table_remove (priv->bytestream_to_transport, bytestream);
+  g_hash_table_remove (priv->bytestream_to_fd, bytestream);
+}
+
+static void
+transport_buffer_empty_cb (GibberTransport *transport,
+                           SalutTubeStream *self)
+{
+  SalutTubeStreamPrivate *priv = SALUT_TUBE_STREAM_GET_PRIVATE (self);
+  GibberBytestreamIface *bytestream;
+  GibberBytestreamState state;
+
+  bytestream = g_hash_table_lookup (priv->transport_to_bytestream, transport);
+  g_assert (bytestream != NULL);
+  g_object_get (bytestream, "state", &state, NULL);
+
+  if (state == GIBBER_BYTESTREAM_STATE_CLOSED)
+    {
+      DEBUG ("buffer is now empty. Transport can be removed");
+      remove_transport (self, transport);
+      return;
+    }
+
+  /* Buffer is empty so we can unblock the buffer if it was blocked */
+  gibber_bytestream_oob_block_read (GIBBER_BYTESTREAM_OOB (bytestream),
+      FALSE);
+}
+
 static void
 add_transport (SalutTubeStream *self,
                GibberTransport *transport,
@@ -209,6 +255,32 @@ add_transport (SalutTubeStream *self,
 
   g_signal_connect (transport, "disconnected",
       G_CALLBACK (transport_disconnected_cb), self);
+  g_signal_connect (transport, "buffer-empty",
+      G_CALLBACK (transport_buffer_empty_cb), self);
+}
+
+static void
+bytestream_write_blocked_cb (GibberBytestreamIface *bytestream,
+                             gboolean blocked,
+                             SalutTubeStream *self)
+{
+  SalutTubeStreamPrivate *priv = SALUT_TUBE_STREAM_GET_PRIVATE (self);
+  GibberTransport *transport;
+
+  transport = g_hash_table_lookup (priv->bytestream_to_transport,
+      bytestream);
+  g_assert (transport != NULL);
+
+  if (blocked)
+    {
+      DEBUG ("bytestream blocked, stop to read data from the tube socket");
+    }
+  else
+    {
+      DEBUG ("bytestream unblocked, restart to read data from the tube socket");
+    }
+
+  gibber_transport_block_receiving (transport, blocked);
 }
 
 static void
@@ -228,6 +300,8 @@ extra_bytestream_state_changed_cb (GibberBytestreamIface *bytestream,
 
       g_signal_connect (bytestream, "data-received",
           G_CALLBACK (data_received_cb), self);
+      g_signal_connect (bytestream, "write-blocked",
+          G_CALLBACK (bytestream_write_blocked_cb), self);
 
       fd = GPOINTER_TO_INT (g_hash_table_lookup (priv->bytestream_to_fd,
             bytestream));
@@ -246,15 +320,16 @@ extra_bytestream_state_changed_cb (GibberBytestreamIface *bytestream,
           bytestream);
       if (transport != NULL)
         {
-          g_signal_handlers_disconnect_matched (transport, G_SIGNAL_MATCH_DATA,
-              0, 0, NULL, NULL, self);
-
-          gibber_transport_disconnect (transport);
-          g_hash_table_remove (priv->transport_to_bytestream, transport);
+          if (gibber_transport_buffer_is_empty (transport))
+            {
+              DEBUG ("Buffer is empty, we can remove the transport");
+              remove_transport (self, transport);
+            }
+          else
+            {
+              DEBUG ("Wait buffer is empty before disconnect the transport");
+            }
         }
-
-      g_hash_table_remove (priv->bytestream_to_transport, bytestream);
-      g_hash_table_remove (priv->bytestream_to_fd, bytestream);
     }
 }
 
@@ -493,7 +568,7 @@ new_connection_to_socket (SalutTubeStream *self,
 
       addr.un.sun_family = PF_UNIX;
       strncpy (addr.un.sun_path, array->data, sizeof (addr.un.sun_path) - 1);
-      addr.un.sun_path[sizeof (addr.un.sun_path)] = '\0';
+      addr.un.sun_path[sizeof (addr.un.sun_path) - 1] = '\0';
       len = sizeof (addr.un);
 
       DEBUG ("Will try to connect to socket: %s", (const gchar *) array->data);
@@ -1222,6 +1297,18 @@ data_received_cb (GibberBytestreamIface *bytestream,
     DEBUG ("sending failed: %s", error->message);
     g_error_free (error);
   }
+
+  if (!gibber_transport_buffer_is_empty (transport))
+    {
+      /* We >don't want to send more data while the buffer isn't empty */
+      /* FIXME: Should we move this as bytestream-iface method? */
+      if (GIBBER_IS_BYTESTREAM_OOB (bytestream))
+          {
+            DEBUG ("tube buffer isn't empty. Block the bytestream");
+            gibber_bytestream_oob_block_read (
+              GIBBER_BYTESTREAM_OOB (bytestream), TRUE);
+          }
+    }
 }
 
 SalutTubeStream *
